@@ -960,7 +960,7 @@ grn_com_sopen(grn_ctx *ctx, grn_com_event *ev,
               const char *bind_address, int port, grn_msg_handler *func,
               struct hostent *he)
 {
-  grn_sock lfd;
+  grn_sock lfd = -1;
   grn_com *cs = NULL;
   int getaddrinfo_result;
   struct addrinfo *bind_address_info = NULL;
@@ -975,7 +975,9 @@ grn_com_sopen(grn_ctx *ctx, grn_com_event *ev,
   memset(&hints, 0, sizeof(struct addrinfo));
   hints.ai_family = PF_UNSPEC;
   hints.ai_socktype = SOCK_STREAM;
+#ifdef AI_NUMERICSERV
   hints.ai_flags = AI_NUMERICSERV;
+#endif
   getaddrinfo_result = getaddrinfo(bind_address, port_string,
                                    &hints, &bind_address_info);
   if (getaddrinfo_result != 0) {
@@ -1040,7 +1042,7 @@ grn_com_sopen(grn_ctx *ctx, grn_com_event *ev,
   }
   cs->accepting = GRN_TRUE;
 exit :
-  if (!cs) { grn_sock_close(lfd); }
+  if (!cs && lfd != 1) { grn_sock_close(lfd); }
   if (bind_address_info) { freeaddrinfo(bind_address_info); }
   GRN_API_RETURN(ctx->rc);
 }
