@@ -1,5 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
-/* Copyright(C) 2009 Brazil
+/*
+  Copyright(C) 2009-2012 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -102,18 +103,12 @@ GRN_API void grn_ctx_impl_err(grn_ctx *ctx);
 #define LOGTRACE(ctx,lvl) {\
   int i;\
   char **p;\
-  grn_obj buf;\
   BACKTRACE(ctx);\
   p = backtrace_symbols((ctx)->trace, (ctx)->ntrace);\
-  GRN_TEXT_INIT(&buf, 0);\
   for (i = 0; i < (ctx)->ntrace; i++) {\
-    if (i) GRN_TEXT_PUTS((ctx), &buf, " <= ");\
-    GRN_TEXT_PUTS((ctx), &buf, p[i]);\
+    GRN_LOG((ctx), lvl, "%s", p[i]);\
   }\
-  GRN_TEXT_PUTC((ctx), &buf, '\0');\
   free(p);\
-  GRN_LOG((ctx), lvl, "%s", GRN_BULK_HEAD(&buf));\
-  grn_obj_close((ctx), &buf);\
 }
 #else  /* HAVE_BACKTRACE */
 #define LOGTRACE(ctx,msg)
@@ -423,7 +418,7 @@ GRN_API grn_rc grn_timeval_now(grn_ctx *ctx, grn_timeval *tv);
 GRN_API grn_rc grn_timeval2str(grn_ctx *ctx, grn_timeval *tv, char *buf);
 grn_rc grn_str2timeval(const char *str, uint32_t str_len, grn_timeval *tv);
 
-GRN_API void grn_ctx_log(grn_ctx *ctx, char *fmt, ...);
+GRN_API void grn_ctx_log(grn_ctx *ctx, const char *fmt, ...);
 void grn_ctx_qe_fin(grn_ctx *ctx);
 void grn_ctx_loader_clear(grn_ctx *ctx);
 void grn_log_reopen(grn_ctx *ctx);
