@@ -15,6 +15,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include "groonga_in.h"
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <cstring>
 #include <new>
 #include "str.h"
@@ -68,7 +70,20 @@ class CriticalSection {
   CriticalSection &operator=(const CriticalSection &);
 };
 
-grn_rc grn_dat_translate_error_code(grn::dat::ErrorCode error_code) {
+/*
+  grn_dat_remove_file() removes a file specified by `path' and then returns
+  true on success, false on failure. Note that grn_dat_remove_file() does not
+  change `ctx->rc'.
+ */
+bool
+grn_dat_remove_file(grn_ctx *ctx, const char *path)
+{
+  struct stat stat;
+  return !::stat(path, &stat) && !unlink(path);
+}
+
+grn_rc
+grn_dat_translate_error_code(grn::dat::ErrorCode error_code) {
   switch (error_code) {
     case grn::dat::PARAM_ERROR: {
       return GRN_INVALID_ARGUMENT;
@@ -83,7 +98,12 @@ grn_rc grn_dat_translate_error_code(grn::dat::ErrorCode error_code) {
       return GRN_NO_MEMORY_AVAILABLE;
     }
     case grn::dat::SIZE_ERROR:
-    case grn::dat::UNEXPECTED_ERROR:
+    case grn::dat::UNEXPECTED_ERROR: {
+      return GRN_UNKNOWN_ERROR;
+    }
+    case grn::dat::STATUS_ERROR: {
+      return GRN_FILE_CORRUPT;
+    }
     default: {
       return GRN_UNKNOWN_ERROR;
     }
@@ -118,6 +138,10 @@ grn_dat_fin(grn_ctx *ctx, grn_dat *dat)
   }
 }
 
+/*
+  grn_dat_generate_trie_path() generates the path from `base_path' and
+  `file_id'. The generated path is stored in `trie_path'.
+ */
 void
 grn_dat_generate_trie_path(const char *base_path, char *trie_path, uint32_t file_id)
 {
@@ -128,7 +152,8 @@ grn_dat_generate_trie_path(const char *base_path, char *trie_path, uint32_t file
   const size_t len = std::strlen(base_path);
   std::memcpy(trie_path, base_path, len);
   trie_path[len] = '.';
-  grn_itoh(file_id % (1U << (4 * FILE_ID_LENGTH)), trie_path + len + 1, FILE_ID_LENGTH);
+  grn_itoh(file_id % (1U << (4 * FILE_ID_LENGTH)),
+           trie_path + len + 1, FILE_ID_LENGTH);
   trie_path[len + 1 + FILE_ID_LENGTH] = '\0';
 }
 
@@ -136,20 +161,26 @@ bool
 grn_dat_open_trie_if_needed(grn_ctx *ctx, grn_dat *dat)
 {
   if (!dat) {
-    ERR(GRN_INVALID_ARGUMENT, const_cast<char *>("dat is null"));
+    ERR(GRN_INVALID_ARGUMENT, "dat is null");
     return false;
   }
 
   const uint32_t file_id = dat->header->file_id;
   if (!file_id || (dat->trie && (file_id <= dat->file_id))) {
-    // There is no need to open file.
+    /*
+      There is no need to open file when no trie file is available or the
+      current trie file is the latest one.
+     */
     return true;
   }
 
   CriticalSection critical_section(&dat->lock);
 
   if (dat->trie && (file_id <= dat->file_id)) {
-    // There is no need to open file if the new file has been opened by another thread.
+    /*
+      There is no need to open file if the latest file has been opened by
+      another thread.
+     */
     return true;
   }
 
@@ -159,7 +190,7 @@ grn_dat_open_trie_if_needed(grn_ctx *ctx, grn_dat *dat)
   grn::dat::Trie * const old_trie = static_cast<grn::dat::Trie *>(dat->old_trie);
   grn::dat::Trie * const new_trie = new (std::nothrow) grn::dat::Trie;
   if (!new_trie) {
-    MERR(const_cast<char *>("new grn::dat::Trie failed"));
+    MERR("new grn::dat::Trie failed");
     return false;
   }
 
@@ -167,7 +198,7 @@ grn_dat_open_trie_if_needed(grn_ctx *ctx, grn_dat *dat)
     new_trie->open(trie_path);
   } catch (const grn::dat::Exception &ex) {
     ERR(grn_dat_translate_error_code(ex.code()),
-        const_cast<char *>("grn::dat::Trie::open failed"));
+        "grn::dat::Trie::open failed");
     delete new_trie;
     return false;
   }
@@ -181,7 +212,7 @@ grn_dat_open_trie_if_needed(grn_ctx *ctx, grn_dat *dat)
   delete old_trie;
   if (file_id >= 3) {
     grn_dat_generate_trie_path(grn_io_path(dat->io), trie_path, file_id - 2);
-    grn_io_remove(ctx, trie_path);
+    grn_dat_remove_file(ctx, trie_path);
   }
   return true;
 }
@@ -189,7 +220,7 @@ grn_dat_open_trie_if_needed(grn_ctx *ctx, grn_dat *dat)
 bool grn_dat_rebuild_trie(grn_ctx *ctx, grn_dat *dat) {
   grn::dat::Trie * const new_trie = new (std::nothrow) grn::dat::Trie;
   if (!new_trie) {
-    MERR(const_cast<char *>("new grn::dat::Trie failed"));
+    MERR("new grn::dat::Trie failed");
     return false;
   }
 
@@ -201,7 +232,7 @@ bool grn_dat_rebuild_trie(grn_ctx *ctx, grn_dat *dat) {
     new_trie->create(*trie, trie_path, trie->file_size() * 2);
   } catch (const grn::dat::Exception &ex) {
     ERR(grn_dat_translate_error_code(ex.code()),
-        const_cast<char *>("grn::dat::Trie::open failed"));
+        "grn::dat::Trie::open failed");
     delete new_trie;
     return false;
   }
@@ -215,7 +246,7 @@ bool grn_dat_rebuild_trie(grn_ctx *ctx, grn_dat *dat) {
   if (file_id >= 2) {
     char trie_path[PATH_MAX];
     grn_dat_generate_trie_path(grn_io_path(dat->io), trie_path, file_id - 1);
-    grn_io_remove(ctx, trie_path);
+    grn_dat_remove_file(ctx, trie_path);
   }
   return true;
 }
@@ -248,7 +279,7 @@ grn_dat_create(grn_ctx *ctx, const char *path, uint32_t,
     if (path[0] == '\0') {
       path = NULL;
     } else if (std::strlen(path) >= (PATH_MAX - (FILE_ID_LENGTH + 1))) {
-      ERR(GRN_FILENAME_TOO_LONG, const_cast<char *>("too long path"));
+      ERR(GRN_FILENAME_TOO_LONG, "too long path");
       return NULL;
     }
   }
@@ -271,7 +302,7 @@ grn_dat_create(grn_ctx *ctx, const char *path, uint32_t,
   dat->header = static_cast<struct grn_dat_header *>(grn_io_header(dat->io));
   if (!dat->header) {
     grn_io_close(ctx, dat->io);
-    grn_io_remove(ctx, path);
+    grn_dat_remove_file(ctx, path);
     GRN_FREE(dat);
     return NULL;
   }
@@ -290,7 +321,7 @@ grn_dat *
 grn_dat_open(grn_ctx *ctx, const char *path)
 {
   if (path && (std::strlen(path) >= (PATH_MAX - (FILE_ID_LENGTH + 1)))) {
-    ERR(GRN_FILENAME_TOO_LONG, const_cast<char *>("too long path"));
+    ERR(GRN_FILENAME_TOO_LONG, "too long path");
     return NULL;
   }
 
@@ -333,7 +364,7 @@ grn_rc
 grn_dat_remove(grn_ctx *ctx, const char *path)
 {
   if (!path) {
-    ERR(GRN_INVALID_ARGUMENT, const_cast<char *>("path is null"));
+    ERR(GRN_INVALID_ARGUMENT, "path is null");
     return GRN_INVALID_ARGUMENT;
   }
 
@@ -344,13 +375,23 @@ grn_dat_remove(grn_ctx *ctx, const char *path)
   const uint32_t file_id = dat->header->file_id;
   grn_dat_close(ctx, dat);
 
+  /*
+    grn_dat_remove() tries to remove (file_id + 1)th trie file because
+    grn::dat::Trie::create() might leave an incomplete file on failure.
+   */
+  char trie_path[PATH_MAX];
+  grn_dat_generate_trie_path(path, trie_path, file_id + 1);
+  grn_dat_remove_file(ctx, trie_path);
   for (uint32_t i = file_id; i > 0; --i) {
-    char trie_path[PATH_MAX];
     grn_dat_generate_trie_path(path, trie_path, i);
-    if (grn_io_remove(ctx, trie_path) != GRN_SUCCESS) {
+    if (!grn_dat_remove_file(ctx, trie_path)) {
       break;
     }
   }
+
+  /*
+    grn_io_remove() reports an error when it fails to remove `path'.
+   */
   return grn_io_remove(ctx, path);
 }
 
@@ -372,7 +413,7 @@ grn_dat_get(grn_ctx *ctx, grn_dat *dat, const void *key,
     }
   } catch (const grn::dat::Exception &ex) {
     ERR(grn_dat_translate_error_code(ex.code()),
-        const_cast<char *>("grn::dat::Trie::search failed"));
+        "grn::dat::Trie::search failed");
   }
   return GRN_ID_NIL;
 }
@@ -390,14 +431,14 @@ grn_dat_add(grn_ctx *ctx, grn_dat *dat, const void *key,
     grn_dat_generate_trie_path(grn_io_path(dat->io), trie_path, 1);
     grn::dat::Trie * const new_trie = new (std::nothrow) grn::dat::Trie;
     if (!new_trie) {
-      MERR(const_cast<char *>("new grn::dat::Trie failed"));
+      MERR("new grn::dat::Trie failed");
       return GRN_ID_NIL;
     }
     try {
       new_trie->create(trie_path);
     } catch (const grn::dat::Exception &ex) {
       ERR(grn_dat_translate_error_code(ex.code()),
-          const_cast<char *>("grn::dat::Trie::create failed"));
+          "grn::dat::Trie::create failed");
       delete new_trie;
       return GRN_ID_NIL;
     }
@@ -426,7 +467,7 @@ grn_dat_add(grn_ctx *ctx, grn_dat *dat, const void *key,
     return new_trie->get_key(key_pos).id();
   } catch (const grn::dat::Exception &ex) {
     ERR(grn_dat_translate_error_code(ex.code()),
-        const_cast<char *>("grn::dat::Trie::insert failed"));
+        "grn::dat::Trie::insert failed");
     return GRN_ID_NIL;
   }
 }
@@ -500,8 +541,8 @@ grn_dat_delete_by_id(grn_ctx *ctx, grn_dat *dat, grn_id id,
     }
   } catch (const grn::dat::Exception &ex) {
     ERR(grn_dat_translate_error_code(ex.code()),
-        const_cast<char *>("grn::dat::Trie::remove failed"));
-    return GRN_INVALID_ARGUMENT;
+        "grn::dat::Trie::remove failed");
+    return ctx->rc;
   }
   return GRN_SUCCESS;
 }
@@ -528,7 +569,8 @@ grn_dat_delete(grn_ctx *ctx, grn_dat *dat, const void *key, unsigned int key_siz
       }
     } catch (const grn::dat::Exception &ex) {
       ERR(grn_dat_translate_error_code(ex.code()),
-          const_cast<char *>("grn::dat::Trie::search failed"));
+          "grn::dat::Trie::search failed");
+      return ctx->rc;
     }
   }
 
@@ -539,8 +581,8 @@ grn_dat_delete(grn_ctx *ctx, grn_dat *dat, const void *key, unsigned int key_siz
     }
   } catch (const grn::dat::Exception &ex) {
     ERR(grn_dat_translate_error_code(ex.code()),
-        const_cast<char *>("grn::dat::Trie::remove failed"));
-    return GRN_INVALID_ARGUMENT;
+        "grn::dat::Trie::remove failed");
+    return ctx->rc;
   }
   return GRN_SUCCESS;
 }
@@ -565,15 +607,14 @@ grn_dat_update_by_id(grn_ctx *ctx, grn_dat *dat, grn_id src_key_id,
         return ctx->rc;
       }
       grn::dat::Trie * const trie = static_cast<grn::dat::Trie *>(dat->trie);
-      grn::dat::UInt32 key_pos;
       if (!trie->update(src_key_id, dest_key, dest_key_size)) {
         return GRN_INVALID_ARGUMENT;
       }
     }
   } catch (const grn::dat::Exception &ex) {
     ERR(grn_dat_translate_error_code(ex.code()),
-        const_cast<char *>("grn::dat::Trie::update failed"));
-    return GRN_INVALID_ARGUMENT;
+        "grn::dat::Trie::update failed");
+    return ctx->rc;
   }
   return GRN_SUCCESS;
 }
@@ -599,19 +640,126 @@ grn_dat_update(grn_ctx *ctx, grn_dat *dat,
         return ctx->rc;
       }
       grn::dat::Trie * const trie = static_cast<grn::dat::Trie *>(dat->trie);
-      grn::dat::UInt32 key_pos;
       if (!trie->update(src_key, src_key_size, dest_key, dest_key_size)) {
         return GRN_INVALID_ARGUMENT;
       }
     }
   } catch (const grn::dat::Exception &ex) {
     ERR(grn_dat_translate_error_code(ex.code()),
-        const_cast<char *>("grn::dat::Trie::update failed"));
-    return GRN_INVALID_ARGUMENT;
+        "grn::dat::Trie::update failed");
+    return ctx->rc;
   }
   return GRN_SUCCESS;
 }
 
+int grn_dat_scan(grn_ctx *ctx, grn_dat *dat, const char *str,
+                 unsigned int str_size, grn_dat_scan_hit *scan_hits,
+                 unsigned int max_num_scan_hits, const char **str_rest) {
+  if (!grn_dat_open_trie_if_needed(ctx, dat) || !str ||
+      !(dat->obj.header.flags & GRN_OBJ_KEY_VAR_SIZE) || !scan_hits) {
+    return -1;
+  }
+
+  grn::dat::Trie * const trie = static_cast<grn::dat::Trie *>(dat->trie);
+  if (!trie) {
+    return -1;
+  }
+
+  if (!max_num_scan_hits || !str_size) {
+    if (str_rest) {
+      *str_rest = str;
+    }
+    return 0;
+  }
+
+  int num_scan_hits = 0;
+  try {
+    if (dat->obj.header.flags & GRN_OBJ_KEY_NORMALIZE) {
+      grn_str * const normalized_str = grn_str_open(
+          ctx, str, str_size, GRN_STR_NORMALIZE | GRN_STR_WITH_CHECKS);
+      if (!normalized_str) {
+        fprintf(stderr, "error: grn_str_open() failed!\n");
+        return -1;
+      }
+      str = normalized_str->norm;
+      str_size = normalized_str->norm_blen;
+      const short *checks = normalized_str->checks;
+      unsigned int offset = 0;
+      while (str_size) {
+        if (*checks) {
+          grn::dat::UInt32 key_pos;
+          if (trie->lcp_search(str, str_size, &key_pos)) {
+            const grn::dat::Key &key = trie->get_key(key_pos);
+            const grn::dat::UInt32 key_length = key.length();
+            if ((key_length == str_size) || (checks[key_length])) {
+              unsigned int length = 0;
+              for (grn::dat::UInt32 i = 0; i < key_length; ++i) {
+                if (checks[i] > 0) {
+                  length += checks[i];
+                }
+              }
+              scan_hits[num_scan_hits].id = key.id();
+              scan_hits[num_scan_hits].offset = offset;
+              scan_hits[num_scan_hits].length = length;
+              offset += length;
+              str += key_length;
+              str_size -= key_length;
+              checks += key_length;
+              if (++num_scan_hits >= max_num_scan_hits) {
+                break;
+              }
+              continue;
+            }
+          }
+          if (*checks > 0) {
+            offset += *checks;
+          }
+        }
+        ++str;
+        --str_size;
+        ++checks;
+      }
+      if (str_rest) {
+        *str_rest = normalized_str->orig + offset;
+      }
+      grn_str_close(ctx, normalized_str);
+    } else {
+      const char * const begin = str;
+      while (str_size) {
+        grn::dat::UInt32 key_pos;
+        if (trie->lcp_search(str, str_size, &key_pos)) {
+          const grn::dat::Key &key = trie->get_key(key_pos);
+          scan_hits[num_scan_hits].id = key.id();
+          scan_hits[num_scan_hits].offset = str - begin;
+          scan_hits[num_scan_hits].length = key.length();
+          str += key.length();
+          str_size -= key.length();
+          if (++num_scan_hits >= max_num_scan_hits) {
+            break;
+          }
+        } else {
+          const int char_length = grn_charlen(ctx, str, str + str_size);
+          if (char_length) {
+            str += char_length;
+            str_size -= char_length;
+          } else {
+            ++str;
+            --str_size;
+          }
+        }
+      }
+      if (str_rest) {
+        *str_rest = str;
+      }
+    }
+  } catch (const grn::dat::Exception &ex) {
+    ERR(grn_dat_translate_error_code(ex.code()),
+        "grn::dat::lcp_search failed");
+    return -1;
+  }
+  return num_scan_hits;
+}
+
 grn_id
 grn_dat_lcp_search(grn_ctx *ctx, grn_dat *dat,
                    const void *key, unsigned int key_size)
@@ -634,7 +782,7 @@ grn_dat_lcp_search(grn_ctx *ctx, grn_dat *dat,
     return trie->get_key(key_pos).id();
   } catch (const grn::dat::Exception &ex) {
     ERR(grn_dat_translate_error_code(ex.code()),
-        const_cast<char *>("grn::dat::PrefixCursor::open failed"));
+        "grn::dat::PrefixCursor::open failed");
     return GRN_ID_NIL;
   }
 }
@@ -717,12 +865,12 @@ grn_dat_cursor_open(grn_ctx *ctx, grn_dat *dat,
     }
   } catch (const grn::dat::Exception &ex) {
     ERR(grn_dat_translate_error_code(ex.code()),
-        const_cast<char *>("grn::dat::CursorFactory::open failed"));
+        "grn::dat::CursorFactory::open failed");
     GRN_FREE(dc);
     return NULL;
   }
   if (!dc->cursor) {
-    ERR(GRN_INVALID_ARGUMENT, const_cast<char *>("unsupported query"));
+    ERR(GRN_INVALID_ARGUMENT, "unsupported query");
     GRN_FREE(dc);
     return NULL;
   }
@@ -743,7 +891,7 @@ grn_dat_cursor_next(grn_ctx *ctx, grn_dat_cursor *c)
     c->curr_rec = key.is_valid() ? key.id() : GRN_ID_NIL;
   } catch (const grn::dat::Exception &ex) {
     ERR(grn_dat_translate_error_code(ex.code()),
-        const_cast<char *>("grn::dat::Cursor::next failed"));
+        "grn::dat::Cursor::next failed");
     return GRN_ID_NIL;
   }
   return c->curr_rec;
@@ -790,7 +938,7 @@ grn_dat_cursor_delete(grn_ctx *ctx, grn_dat_cursor *c,
     }
   } catch (const grn::dat::Exception &ex) {
     ERR(grn_dat_translate_error_code(ex.code()),
-        const_cast<char *>("grn::dat::Trie::remove failed"));
+        "grn::dat::Trie::remove failed");
     return GRN_INVALID_ARGUMENT;
   }
   return GRN_INVALID_ARGUMENT;
@@ -826,7 +974,7 @@ grn_dat_truncate(grn_ctx *ctx, grn_dat *dat)
     grn::dat::Trie().create(trie_path);
   } catch (const grn::dat::Exception &ex) {
     const grn_rc error_code = grn_dat_translate_error_code(ex.code());
-    ERR(error_code, const_cast<char *>("grn::dat::Trie::create failed"));
+    ERR(error_code, "grn::dat::Trie::create failed");
     return error_code;
   }
   ++dat->header->file_id;
@@ -889,4 +1037,45 @@ grn_dat_at(grn_ctx *ctx, grn_dat *dat, grn_id id)
   return id;
 }
 
+grn_rc
+grn_dat_clear_status_flags(grn_ctx *ctx, grn_dat *dat)
+{
+  if (!grn_dat_open_trie_if_needed(ctx, dat)) {
+    return ctx->rc;
+  }
+  grn::dat::Trie * const trie = static_cast<grn::dat::Trie *>(dat->trie);
+  if (!trie) {
+    return GRN_INVALID_ARGUMENT;
+  }
+  trie->clear_status_flags();
+  return GRN_SUCCESS;
+}
+
+grn_rc
+grn_dat_repair(grn_ctx *ctx, grn_dat *dat)
+{
+  if (!grn_dat_open_trie_if_needed(ctx, dat)) {
+    return ctx->rc;
+  }
+  const grn::dat::Trie * const trie = static_cast<grn::dat::Trie *>(dat->trie);
+  if (!trie) {
+    return GRN_INVALID_ARGUMENT;
+  }
+
+  char trie_path[PATH_MAX];
+  grn_dat_generate_trie_path(grn_io_path(dat->io), trie_path, dat->header->file_id + 1);
+  try {
+    grn::dat::Trie().repair(*trie, trie_path);
+  } catch (const grn::dat::Exception &ex) {
+    const grn_rc error_code = grn_dat_translate_error_code(ex.code());
+    ERR(error_code, "grn::dat::Trie::create failed");
+    return error_code;
+  }
+  ++dat->header->file_id;
+  if (!grn_dat_open_trie_if_needed(ctx, dat)) {
+    return ctx->rc;
+  }
+  return GRN_SUCCESS;
+}
+
 }  // extern "C"
