@@ -25,12 +25,10 @@ namespace dat {
 
 class Block {
  public:
-  Block()
-      : next_(0),
-        prev_(0),
-        first_phantom_(0),
-        num_phantoms_(0) {}
+  Block() : next_(0), prev_(0), first_phantom_(0), num_phantoms_(0) {}
 
+  // Blocks in the same level are stored in a doubly-linked list which is
+  // represented by the following next() and prev().
   UInt32 next() const {
     return next_ / BLOCK_SIZE;
   }
@@ -38,10 +36,14 @@ class Block {
     return prev_ / BLOCK_SIZE;
   }
 
+  // A level indicates how easyily find_offset() can find a good offset in that
+  // block. It is easier in lower level blocks.
   UInt32 level() const {
     return next_ & BLOCK_MASK;
   }
-  UInt32 fail_count() const {
+  // A block level rises when find_offset() fails to find a good offset
+  // MAX_FAILURE_COUNT times in that block.
+  UInt32 failure_count() const {
     return prev_ & BLOCK_MASK;
   }
 
@@ -66,14 +68,14 @@ class Block {
     GRN_DAT_DEBUG_THROW_IF(x > BLOCK_MASK);
     next_ = (next_ & ~BLOCK_MASK) | x;
   }
-  void set_fail_count(UInt32 x) {
-    GRN_DAT_DEBUG_THROW_IF(x > MAX_FAIL_COUNT);
+  void set_failure_count(UInt32 x) {
+    GRN_DAT_DEBUG_THROW_IF(x > MAX_FAILURE_COUNT);
     GRN_DAT_DEBUG_THROW_IF(x > BLOCK_MASK);
     prev_ = (prev_ & ~BLOCK_MASK) | x;
   }
 
   void set_first_phantom(UInt32 x) {
-    GRN_DAT_DEBUG_THROW_IF(x > BLOCK_MASK);
+    GRN_DAT_DEBUG_THROW_IF(x >= BLOCK_SIZE);
     first_phantom_ = (UInt16)x;
   }
   void set_num_phantoms(UInt32 x) {
@@ -86,8 +88,6 @@ class Block {
   UInt32 prev_;
   UInt16 first_phantom_;
   UInt16 num_phantoms_;
-
-  static const UInt32 SHIFT = 9;
 };
 
 }  // namespace dat
