@@ -268,7 +268,7 @@ grn_geo_table_sort_detect_far_point(grn_ctx *ctx, grn_obj *table, grn_obj *index
       grn_gton(geo_key_prev, &point, sizeof(grn_geo_point));
       grn_pat_get_key(ctx, pat, tid, &point, sizeof(grn_geo_point));
       grn_gton(geo_key_curr, &point, sizeof(grn_geo_point));
-      d = grn_geo_distance_raw(ctx, base_point, &point);
+      d = grn_geo_distance_rectangle_raw(ctx, base_point, &point);
       inspect_tid(ctx, tid, &point, d);
 
       diff_bit_prev = diff_bit_current;
@@ -480,7 +480,8 @@ grn_geo_get_meshes_for_circle(grn_ctx *ctx, grn_geo_point *base_point,
         }
         meshes[n_meshes].key.latitude = lat;
         meshes[n_meshes].key.longitude = lng;
-        d = grn_geo_distance_raw(ctx, base_point, &(meshes[n_meshes].key));
+        d = grn_geo_distance_rectangle_raw(ctx, base_point,
+                                           &(meshes[n_meshes].key));
         if (d < d_far) {
 #ifdef GEO_DEBUG
           printf("sub-mesh: %d: (%d,%d): (%d,%d;%d,%d)\n",
@@ -537,7 +538,7 @@ grn_geo_table_sort_collect_points(grn_ctx *ctx, grn_obj *table, grn_obj *index,
           grn_geo_point pos;
           grn_ii_posting *posting;
           grn_pat_get_key(ctx, pat, tid, &pos, sizeof(grn_geo_point));
-          d = grn_geo_distance_raw(ctx, base_point, &pos);
+          d = grn_geo_distance_rectangle_raw(ctx, base_point, &pos);
           inspect_tid(ctx, tid, &pos, d);
           while ((posting = grn_ii_cursor_next(ctx, ic))) {
             grn_id rid = accessorp
@@ -630,34 +631,116 @@ grn_geo_table_sort(grn_ctx *ctx, grn_obj *table, int offset, int limit,
   return i;
 }
 
+grn_rc
+grn_geo_resolve_approximate_type(grn_ctx *ctx, grn_obj *type_name,
+                                 grn_geo_approximate_type *type)
+{
+  grn_rc rc;
+  grn_obj approximate_type;
+
+  GRN_TEXT_INIT(&approximate_type, 0);
+  rc = grn_obj_cast(ctx, type_name, &approximate_type, GRN_FALSE);
+  if (rc == GRN_SUCCESS) {
+    const char *name;
+    unsigned int size;
+    name = GRN_TEXT_VALUE(&approximate_type);
+    size = GRN_TEXT_LEN(&approximate_type);
+    if ((strncmp("rectangle", name, size) == 0) ||
+        (strncmp("rect", name, size) == 0)) {
+      *type = GRN_GEO_APPROXIMATE_RECTANGLE;
+    } else if ((strncmp("sphere", name, size) == 0) ||
+               (strncmp("sphr", name, size) == 0)) {
+      *type = GRN_GEO_APPROXIMATE_SPHERE;
+    } else if ((strncmp("ellipsoid", name, size) == 0) ||
+               (strncmp("ellip", name, size) == 0)) {
+      *type = GRN_GEO_APPROXIMATE_ELLIPSOID;
+    } else {
+      ERR(GRN_INVALID_ARGUMENT,
+          "geo distance approximate type must be one of "
+          "[rectangle, rect, sphere, sphr, ellipsoid, ellip]"
+          ": <%.*s>",
+          size, name);
+    }
+  }
+  GRN_OBJ_FIN(ctx, &approximate_type);
+
+  return rc;
+}
+
+typedef double (*grn_geo_distance_raw_func)(grn_ctx *ctx,
+                                            grn_geo_point *point1,
+                                            grn_geo_point *point2);
+
 grn_rc
 grn_selector_geo_in_circle(grn_ctx *ctx, grn_obj *obj, grn_obj **args, int nargs,
                            grn_obj *res, grn_operator op)
 {
-  if (nargs == 4) {
-    grn_obj *center_point, *distance;
-    center_point = args[2];
-    distance = args[3];
-    grn_geo_select_in_circle(ctx, obj, center_point, distance, res, op);
-  } else {
+  grn_geo_approximate_type type = GRN_GEO_APPROXIMATE_RECTANGLE;
+
+  switch (nargs) {
+  case 5 :
+    if (grn_geo_resolve_approximate_type(ctx, args[4], &type) != GRN_SUCCESS) {
+      break;
+    }
+    /* fallthru */
+  case 4 :
+    {
+      grn_obj *center_point, *distance;
+      center_point = args[2];
+      distance = args[3];
+      grn_geo_select_in_circle(ctx, obj, center_point, distance, type, res, op);
+    }
+    break;
+  default :
     ERR(GRN_INVALID_ARGUMENT,
-        "geo_in_circle(): requires 3 arguments but was <%d> arguments",
+        "geo_in_circle(): requires 3 or 4 arguments but was <%d> arguments",
         nargs - 1);
+    break;
   }
+
   return ctx->rc;
 }
 
+static grn_geo_distance_raw_func
+grn_geo_resolve_distance_raw_func (grn_ctx *ctx,
+                                   grn_geo_approximate_type approximate_type,
+                                   grn_id domain)
+{
+  grn_geo_distance_raw_func distance_raw_func = NULL;
+
+  switch (approximate_type) {
+  case GRN_GEO_APPROXIMATE_RECTANGLE :
+    distance_raw_func = grn_geo_distance_rectangle_raw;
+    break;
+  case GRN_GEO_APPROXIMATE_SPHERE :
+    distance_raw_func = grn_geo_distance_sphere_raw;
+    break;
+  case GRN_GEO_APPROXIMATE_ELLIPSOID :
+    if (domain == GRN_DB_WGS84_GEO_POINT) {
+      distance_raw_func = grn_geo_distance_ellipsoid_raw_wgs84;
+    } else {
+      distance_raw_func = grn_geo_distance_ellipsoid_raw_tokyo;
+    }
+    break;
+  default :
+    break;
+  }
+
+  return distance_raw_func;
+}
+
 grn_rc
 grn_geo_select_in_circle(grn_ctx *ctx, grn_obj *index,
                          grn_obj *center_point, grn_obj *distance,
+                         grn_geo_approximate_type approximate_type,
                          grn_obj *res, grn_operator op)
 {
   grn_id domain;
   double center_longitude, center_latitude;
-  double on_circle_longitude, on_circle_latitude;
-  double x, y, d;
+  double d;
   grn_obj *pat, *point_on_circle = NULL, center_point_, point_on_circle_;
   grn_geo_point *center, on_circle;
+  grn_geo_distance_raw_func distance_raw_func;
   pat = grn_ctx_at(ctx, index->header.domain);
   domain = pat->header.domain;
   if (domain != GRN_DB_TOKYO_GEO_POINT && domain != GRN_DB_WGS84_GEO_POINT) {
@@ -687,36 +770,41 @@ grn_geo_select_in_circle(grn_ctx *ctx, grn_obj *index,
   center = GRN_GEO_POINT_VALUE_RAW(center_point);
   center_longitude = GRN_GEO_INT2RAD(center->longitude);
   center_latitude = GRN_GEO_INT2RAD(center->latitude);
+
+  distance_raw_func = grn_geo_resolve_distance_raw_func(ctx,
+                                                        approximate_type,
+                                                        domain);
+  if (!distance_raw_func) {
+    ERR(GRN_INVALID_ARGUMENT,
+        "unknown approximate type: <%d>", approximate_type);
+    goto exit;
+  }
+
   switch (distance->header.domain) {
   case GRN_DB_INT32 :
-    d = GRN_INT32_VALUE(distance) / (double)GRN_GEO_RADIUS;
-    on_circle.latitude = center->latitude + GRN_GEO_RAD2INT(d);
+    d = GRN_INT32_VALUE(distance);
+    on_circle.latitude = center->latitude + GRN_GEO_RAD2INT(d / (double)GRN_GEO_RADIUS);
     on_circle.longitude = center->longitude;
-    d = d * d;
     break;
   case GRN_DB_UINT32 :
-    d = GRN_UINT32_VALUE(distance) / (double)GRN_GEO_RADIUS;
-    on_circle.latitude = center->latitude + GRN_GEO_RAD2INT(d);
+    d = GRN_UINT32_VALUE(distance);
+    on_circle.latitude = center->latitude + GRN_GEO_RAD2INT(d / (double)GRN_GEO_RADIUS);
     on_circle.longitude = center->longitude;
-    d = d * d;
     break;
   case GRN_DB_INT64 :
-    d = GRN_INT64_VALUE(distance) / (double)GRN_GEO_RADIUS;
-    on_circle.latitude = center->latitude + GRN_GEO_RAD2INT(d);
+    d = GRN_INT64_VALUE(distance);
+    on_circle.latitude = center->latitude + GRN_GEO_RAD2INT(d / (double)GRN_GEO_RADIUS);
     on_circle.longitude = center->longitude;
-    d = d * d;
     break;
   case GRN_DB_UINT64 :
-    d = GRN_UINT64_VALUE(distance) / (double)GRN_GEO_RADIUS;
-    on_circle.latitude = center->latitude + GRN_GEO_RAD2INT(d);
+    d = GRN_UINT64_VALUE(distance);
+    on_circle.latitude = center->latitude + GRN_GEO_RAD2INT(d / (double)GRN_GEO_RADIUS);
     on_circle.longitude = center->longitude;
-    d = d * d;
     break;
   case GRN_DB_FLOAT :
-    d = GRN_FLOAT_VALUE(distance) / (double)GRN_GEO_RADIUS;
-    on_circle.latitude = center->latitude + GRN_GEO_RAD2INT(d);
+    d = GRN_FLOAT_VALUE(distance);
+    on_circle.latitude = center->latitude + GRN_GEO_RAD2INT(d / (double)GRN_GEO_RADIUS);
     on_circle.longitude = center->longitude;
-    d = d * d;
     break;
   case GRN_DB_SHORT_TEXT :
   case GRN_DB_TEXT :
@@ -731,12 +819,7 @@ grn_geo_select_in_circle(grn_ctx *ctx, grn_obj *index,
     if (!point_on_circle) { point_on_circle = distance; }
     GRN_GEO_POINT_VALUE(point_on_circle,
                         on_circle.latitude, on_circle.longitude);
-    on_circle_longitude = GRN_GEO_INT2RAD(on_circle.longitude);
-    on_circle_latitude = GRN_GEO_INT2RAD(on_circle.latitude);
-    x = (on_circle_longitude - center_longitude) *
-      cos((center_latitude + on_circle_latitude) * 0.5);
-    y = (on_circle_latitude - center_latitude);
-    d = ((x * x) + (y * y));
+    d = distance_raw_func(ctx, center, &on_circle);
     if (point_on_circle == &point_on_circle_) {
       grn_obj_unlink(ctx, point_on_circle);
     }
@@ -751,7 +834,7 @@ grn_geo_select_in_circle(grn_ctx *ctx, grn_obj *index,
     uint8_t geo_key1[sizeof(grn_geo_point)];
     uint8_t geo_key2[sizeof(grn_geo_point)];
 
-    d_far = grn_geo_distance_raw(ctx, center, &on_circle);
+    d_far = grn_geo_distance_rectangle_raw(ctx, center, &on_circle);
     grn_gton(geo_key1, center, sizeof(grn_geo_point));
     grn_gton(geo_key2, &on_circle, sizeof(grn_geo_point));
     diff_bit = compute_diff_bit(geo_key1, geo_key2);
@@ -780,16 +863,12 @@ grn_geo_select_in_circle(grn_ctx *ctx, grn_obj *index,
       if (tc) {
         grn_id tid;
         grn_geo_point point;
-        double longitude, latitude;
         while ((tid = grn_table_cursor_next(ctx, tc))) {
+          double point_distance;
           grn_table_get_key(ctx, pat, tid, &point, sizeof(grn_geo_point));
-          longitude = GRN_GEO_INT2RAD(point.longitude);
-          latitude = GRN_GEO_INT2RAD(point.latitude);
-          x = (center_longitude - longitude) *
-            cos((latitude + center_latitude) * 0.5);
-          y = (center_latitude - latitude);
-          if (((x * x) + (y * y)) <= d) {
-            inspect_tid(ctx, tid, &point, (x * x) + (y * y));
+          point_distance = distance_raw_func(ctx, &point, center);
+          if (point_distance <= d) {
+            inspect_tid(ctx, tid, &point, point_distance);
             grn_ii_at(ctx, (grn_ii *)index, tid, (grn_hash *)res, op);
           }
         }
@@ -1637,38 +1716,47 @@ exit :
 
 grn_bool
 grn_geo_in_circle(grn_ctx *ctx, grn_obj *point, grn_obj *center,
-                  grn_obj *radius_or_point)
+                  grn_obj *radius_or_point,
+                  grn_geo_approximate_type approximate_type)
 {
   grn_bool r = GRN_FALSE;
   grn_obj center_, radius_or_point_;
   grn_id domain = point->header.domain;
   if (domain == GRN_DB_TOKYO_GEO_POINT || domain == GRN_DB_WGS84_GEO_POINT) {
-    double lng0, lat0, lng1, lat1, lng2, lat2, x, y, d;
+    grn_geo_distance_raw_func distance_raw_func;
+    double d;
     if (center->header.domain != domain) {
       GRN_OBJ_INIT(&center_, GRN_BULK, 0, domain);
       if (grn_obj_cast(ctx, center, &center_, 0)) { goto exit; }
       center = &center_;
     }
-    GRN_GEO_POINT_VALUE_RADIUS(point, lat0, lng0);
-    GRN_GEO_POINT_VALUE_RADIUS(center, lat1, lng1);
-    x = (lng1 - lng0) * cos((lat0 + lat1) * 0.5);
-    y = (lat1 - lat0);
-    d = (x * x) + (y * y);
+
+    distance_raw_func = grn_geo_resolve_distance_raw_func(ctx,
+                                                          approximate_type,
+                                                          domain);
+    if (!distance_raw_func) {
+      ERR(GRN_INVALID_ARGUMENT,
+          "unknown approximate type: <%d>", approximate_type);
+      goto exit;
+    }
+    d = distance_raw_func(ctx,
+                          GRN_GEO_POINT_VALUE_RAW(point),
+                          GRN_GEO_POINT_VALUE_RAW(center));
     switch (radius_or_point->header.domain) {
     case GRN_DB_INT32 :
-      r = (sqrt(d) * GRN_GEO_RADIUS) <= GRN_INT32_VALUE(radius_or_point);
+      r = d <= GRN_INT32_VALUE(radius_or_point);
       break;
     case GRN_DB_UINT32 :
-      r = (sqrt(d) * GRN_GEO_RADIUS) <= GRN_UINT32_VALUE(radius_or_point);
+      r = d <= GRN_UINT32_VALUE(radius_or_point);
       break;
     case GRN_DB_INT64 :
-      r = (sqrt(d) * GRN_GEO_RADIUS) <= GRN_INT64_VALUE(radius_or_point);
+      r = d <= GRN_INT64_VALUE(radius_or_point);
       break;
     case GRN_DB_UINT64 :
-      r = (sqrt(d) * GRN_GEO_RADIUS) <= GRN_UINT64_VALUE(radius_or_point);
+      r = d <= GRN_UINT64_VALUE(radius_or_point);
       break;
     case GRN_DB_FLOAT :
-      r = (sqrt(d) * GRN_GEO_RADIUS) <= GRN_FLOAT_VALUE(radius_or_point);
+      r = d <= GRN_FLOAT_VALUE(radius_or_point);
       break;
     case GRN_DB_SHORT_TEXT :
     case GRN_DB_TEXT :
@@ -1680,10 +1768,9 @@ grn_geo_in_circle(grn_ctx *ctx, grn_obj *point, grn_obj *center,
     case GRN_DB_TOKYO_GEO_POINT :
     case GRN_DB_WGS84_GEO_POINT :
       if (domain != radius_or_point->header.domain) { /* todo */ goto exit; }
-      GRN_GEO_POINT_VALUE_RADIUS(radius_or_point, lat2, lng2);
-      x = (lng2 - lng1) * cos((lat1 + lat2) * 0.5);
-      y = (lat2 - lat1);
-      r = d <= (x * x) + (y * y);
+      r = d <= distance_raw_func(ctx,
+                          GRN_GEO_POINT_VALUE_RAW(radius_or_point),
+                          GRN_GEO_POINT_VALUE_RAW(center));
       break;
     default :
       goto exit;
@@ -1735,7 +1822,8 @@ exit :
 }
 
 double
-grn_geo_distance_raw(grn_ctx *ctx, grn_geo_point *point1, grn_geo_point *point2)
+grn_geo_distance_rectangle_raw(grn_ctx *ctx,
+                               grn_geo_point *point1, grn_geo_point *point2)
 {
   double lng1, lat1, lng2, lat2, x, y;
 
@@ -1749,7 +1837,8 @@ grn_geo_distance_raw(grn_ctx *ctx, grn_geo_point *point1, grn_geo_point *point2)
 }
 
 double
-grn_geo_distance2_raw(grn_ctx *ctx, grn_geo_point *point1, grn_geo_point *point2)
+grn_geo_distance_sphere_raw(grn_ctx *ctx,
+                            grn_geo_point *point1, grn_geo_point *point2)
 {
   double lng1, lat1, lng2, lat2, x, y;
 
@@ -1763,8 +1852,9 @@ grn_geo_distance2_raw(grn_ctx *ctx, grn_geo_point *point1, grn_geo_point *point2
 }
 
 double
-grn_geo_distance3_raw(grn_ctx *ctx, grn_geo_point *point1, grn_geo_point *point2,
-                      int c1, int c2, double c3)
+grn_geo_distance_ellipsoid_raw(grn_ctx *ctx,
+                               grn_geo_point *point1, grn_geo_point *point2,
+                               int c1, int c2, double c3)
 {
   double lng1, lat1, lng2, lat2, p, q, r, m, n, x, y;
 
@@ -1783,7 +1873,52 @@ grn_geo_distance3_raw(grn_ctx *ctx, grn_geo_point *point1, grn_geo_point *point2
 }
 
 double
-grn_geo_distance(grn_ctx *ctx, grn_obj *point1, grn_obj *point2)
+grn_geo_distance_ellipsoid_raw_tokyo(grn_ctx *ctx,
+                                     grn_geo_point *point1,
+                                     grn_geo_point *point2)
+{
+  return grn_geo_distance_ellipsoid_raw(ctx, point1, point2,
+                                        GRN_GEO_BES_C1,
+                                        GRN_GEO_BES_C2,
+                                        GRN_GEO_BES_C3);
+}
+
+double
+grn_geo_distance_ellipsoid_raw_wgs84(grn_ctx *ctx,
+                                     grn_geo_point *point1,
+                                     grn_geo_point *point2)
+{
+  return grn_geo_distance_ellipsoid_raw(ctx, point1, point2,
+                                        GRN_GEO_GRS_C1,
+                                        GRN_GEO_GRS_C2,
+                                        GRN_GEO_GRS_C3);
+}
+
+double
+grn_geo_distance(grn_ctx *ctx, grn_obj *point1, grn_obj *point2,
+                 grn_geo_approximate_type type)
+{
+  double d = 0.0;
+
+  switch (type) {
+  case GRN_GEO_APPROXIMATE_RECTANGLE :
+    d = grn_geo_distance_rectangle(ctx, point1, point2);
+    break;
+  case GRN_GEO_APPROXIMATE_SPHERE :
+    d = grn_geo_distance_sphere(ctx, point1, point2);
+    break;
+  case GRN_GEO_APPROXIMATE_ELLIPSOID :
+    d = grn_geo_distance_ellipsoid(ctx, point1, point2);
+    break;
+  default :
+    ERR(GRN_INVALID_ARGUMENT, "unknown approximate type: <%d>", type);
+    break;
+  }
+  return d;
+}
+
+double
+grn_geo_distance_rectangle(grn_ctx *ctx, grn_obj *point1, grn_obj *point2)
 {
   double d = 0;
   grn_bool point1_initialized = GRN_FALSE;
@@ -1818,9 +1953,9 @@ grn_geo_distance(grn_ctx *ctx, grn_obj *point1, grn_obj *point2)
   } else {
     goto exit;
   }
-  d = grn_geo_distance_raw(ctx,
-                           GRN_GEO_POINT_VALUE_RAW(point1),
-                           GRN_GEO_POINT_VALUE_RAW(point2));
+  d = grn_geo_distance_rectangle_raw(ctx,
+                                     GRN_GEO_POINT_VALUE_RAW(point1),
+                                     GRN_GEO_POINT_VALUE_RAW(point2));
 exit :
   if (point1_initialized) {
     GRN_OBJ_FIN(ctx, &point1_);
@@ -1832,7 +1967,7 @@ exit :
 }
 
 double
-grn_geo_distance2(grn_ctx *ctx, grn_obj *point1, grn_obj *point2)
+grn_geo_distance_sphere(grn_ctx *ctx, grn_obj *point1, grn_obj *point2)
 {
   double d = 0;
   grn_bool point2_initialized = GRN_FALSE;
@@ -1845,9 +1980,9 @@ grn_geo_distance2(grn_ctx *ctx, grn_obj *point1, grn_obj *point2)
       if (grn_obj_cast(ctx, point2, &point2_, 0)) { goto exit; }
       point2 = &point2_;
     }
-    d = grn_geo_distance2_raw(ctx,
-                              GRN_GEO_POINT_VALUE_RAW(point1),
-                              GRN_GEO_POINT_VALUE_RAW(point2));
+    d = grn_geo_distance_sphere_raw(ctx,
+                                    GRN_GEO_POINT_VALUE_RAW(point1),
+                                    GRN_GEO_POINT_VALUE_RAW(point2));
   } else {
     /* todo */
   }
@@ -1859,7 +1994,7 @@ exit :
 }
 
 double
-grn_geo_distance3(grn_ctx *ctx, grn_obj *point1, grn_obj *point2)
+grn_geo_distance_ellipsoid(grn_ctx *ctx, grn_obj *point1, grn_obj *point2)
 {
   double d = 0;
   grn_bool point2_initialized = GRN_FALSE;
@@ -1873,15 +2008,13 @@ grn_geo_distance3(grn_ctx *ctx, grn_obj *point1, grn_obj *point2)
       point2 = &point2_;
     }
     if (domain == GRN_DB_TOKYO_GEO_POINT) {
-      d = grn_geo_distance3_raw(ctx,
-                                GRN_GEO_POINT_VALUE_RAW(point1),
-                                GRN_GEO_POINT_VALUE_RAW(point2),
-                                GRN_GEO_BES_C1, GRN_GEO_BES_C2, GRN_GEO_BES_C3);
+      d = grn_geo_distance_ellipsoid_raw_tokyo(ctx,
+                                               GRN_GEO_POINT_VALUE_RAW(point1),
+                                               GRN_GEO_POINT_VALUE_RAW(point2));
     } else {
-      d = grn_geo_distance3_raw(ctx,
-                                GRN_GEO_POINT_VALUE_RAW(point1),
-                                GRN_GEO_POINT_VALUE_RAW(point2),
-                                GRN_GEO_GRS_C1, GRN_GEO_GRS_C2, GRN_GEO_GRS_C3);
+      d = grn_geo_distance_ellipsoid_raw_wgs84(ctx,
+                                               GRN_GEO_POINT_VALUE_RAW(point1),
+                                               GRN_GEO_POINT_VALUE_RAW(point2));
     }
   } else {
     /* todo */
