@@ -54,7 +54,7 @@ put_delimiter(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type)
       GRN_TEXT_PUTC(ctx, outbuf, '\t');
     }
   case GRN_CONTENT_MSGPACK :
-    // todo
+    // do nothing
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -80,7 +80,15 @@ grn_output_array_open(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_typ
     if (DEPTH > 2) { GRN_TEXT_PUTS(ctx, outbuf, "[\t"); }
     break;
   case GRN_CONTENT_MSGPACK :
-    // todo
+#ifdef HAVE_MESSAGE_PACK
+    if (nelements < 0) {
+      GRN_LOG(ctx, GRN_LOG_DEBUG,
+              "grn_output_array_open nelements (%d) for <%s>",
+              nelements,
+              name);
+    }
+    msgpack_pack_array(&ctx->impl->msgpacker, nelements);
+#endif
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -111,7 +119,7 @@ grn_output_array_close(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_ty
     }
     break;
   case GRN_CONTENT_MSGPACK :
-    // todo
+    // do nothing
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -139,7 +147,15 @@ grn_output_map_open(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type,
     if (DEPTH > 2) { GRN_TEXT_PUTS(ctx, outbuf, "{\t"); }
     break;
   case GRN_CONTENT_MSGPACK :
-    // todo
+#ifdef HAVE_MESSAGE_PACK
+    if (nelements < 0) {
+      GRN_LOG(ctx, GRN_LOG_DEBUG,
+              "grn_output_map_open nelements (%d) for <%s>",
+              nelements,
+              name);
+    }
+    msgpack_pack_map(&ctx->impl->msgpacker, nelements / 2);
+#endif
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -170,7 +186,7 @@ grn_output_map_close(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type
     }
     break;
   case GRN_CONTENT_MSGPACK :
-    // todo
+    // do nothing
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -196,7 +212,9 @@ grn_output_int32(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type, in
     GRN_TEXT_PUTS(ctx, outbuf, "</INT>");
     break;
   case GRN_CONTENT_MSGPACK :
-    // todo
+#ifdef HAVE_MESSAGE_PACK
+    msgpack_pack_int32(&ctx->impl->msgpacker, value);
+#endif
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -221,7 +239,9 @@ grn_output_int64(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type, in
     GRN_TEXT_PUTS(ctx, outbuf, "</INT>");
     break;
   case GRN_CONTENT_MSGPACK :
-    // todo
+#ifdef HAVE_MESSAGE_PACK
+    msgpack_pack_int64(&ctx->impl->msgpacker, value);
+#endif
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -246,7 +266,9 @@ grn_output_uint64(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type, i
     GRN_TEXT_PUTS(ctx, outbuf, "</INT>");
     break;
   case GRN_CONTENT_MSGPACK :
-    // todo
+#ifdef HAVE_MESSAGE_PACK
+    msgpack_pack_uint64(&ctx->impl->msgpacker, value);
+#endif
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -271,7 +293,9 @@ grn_output_float(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type, do
     GRN_TEXT_PUTS(ctx, outbuf, "</FLOAT>");
     break;
   case GRN_CONTENT_MSGPACK :
-    // todo
+#ifdef HAVE_MESSAGE_PACK
+    msgpack_pack_double(&ctx->impl->msgpacker, value);
+#endif
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -297,7 +321,10 @@ grn_output_str(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type,
     GRN_TEXT_PUTS(ctx, outbuf, "</TEXT>");
     break;
   case GRN_CONTENT_MSGPACK :
-    // todo
+#ifdef HAVE_MESSAGE_PACK
+    msgpack_pack_raw(&ctx->impl->msgpacker, value_len);
+    msgpack_pack_raw_body(&ctx->impl->msgpacker, value, value_len);
+#endif
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -329,7 +356,13 @@ grn_output_bool(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type, cha
     GRN_TEXT_PUTS(ctx, outbuf, "</BOOL>");
     break;
   case GRN_CONTENT_MSGPACK :
-    // todo
+#ifdef HAVE_MESSAGE_PACK
+    if (value) {
+      msgpack_pack_true(&ctx->impl->msgpacker);
+    } else {
+      msgpack_pack_false(&ctx->impl->msgpacker);
+    }
+#endif
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -353,7 +386,9 @@ grn_output_void(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type,
       GRN_TEXT_PUTS(ctx, outbuf, "<NULL/>");
       break;
     case GRN_CONTENT_MSGPACK :
-      // todo
+#ifdef HAVE_MESSAGE_PACK
+      msgpack_pack_nil(&ctx->impl->msgpacker);
+#endif
       break;
     case GRN_CONTENT_NONE:
       break;
@@ -383,7 +418,9 @@ grn_output_time(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type, int
     GRN_TEXT_PUTS(ctx, outbuf, "</DATE>");
     break;
   case GRN_CONTENT_MSGPACK :
-    // todo
+#ifdef HAVE_MESSAGE_PACK
+    msgpack_pack_double(&ctx->impl->msgpacker, dv);
+#endif
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -405,7 +442,7 @@ grn_output_geo_point(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type
       grn_text_itoa(ctx, outbuf, value->longitude);
       GRN_TEXT_PUTC(ctx, outbuf, '"');
     } else {
-      GRN_TEXT_PUTS(ctx, outbuf, "\"\"");
+      GRN_TEXT_PUTS(ctx, outbuf, "null");
     }
     break;
   case GRN_CONTENT_TSV:
@@ -429,7 +466,22 @@ grn_output_geo_point(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type
     GRN_TEXT_PUTS(ctx, outbuf, "</GEO_POINT>");
     break;
   case GRN_CONTENT_MSGPACK :
-    // todo
+#ifdef HAVE_MESSAGE_PACK
+    if (value) {
+      grn_obj buf;
+      GRN_TEXT_INIT(&buf, 0);
+      grn_text_itoa(ctx, &buf, value->latitude);
+      GRN_TEXT_PUTC(ctx, &buf, 'x');
+      grn_text_itoa(ctx, &buf, value->longitude);
+      msgpack_pack_raw(&ctx->impl->msgpacker, GRN_TEXT_LEN(&buf));
+      msgpack_pack_raw_body(&ctx->impl->msgpacker,
+                            GRN_TEXT_VALUE(&buf),
+                            GRN_TEXT_LEN(&buf));
+      grn_obj_close(ctx, &buf);
+    } else {
+      msgpack_pack_nil(&ctx->impl->msgpacker);
+    }
+#endif
     break;
   case GRN_CONTENT_NONE:
     break;
@@ -808,7 +860,7 @@ grn_output_obj(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type,
       } else {
         grn_id *v = (grn_id *)GRN_BULK_HEAD(obj),
                *ve = (grn_id *)GRN_BULK_CURR(obj);
-        grn_output_array_open(ctx, outbuf, output_type, "VECTOR", -1);
+        grn_output_array_open(ctx, outbuf, output_type, "VECTOR", ve - v);
         if (v < ve) {
           grn_obj key;
           GRN_OBJ_INIT(&key, GRN_BULK, 0, range->header.domain);
@@ -897,16 +949,28 @@ grn_output_obj(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type,
       grn_table_cursor *tc = grn_table_cursor_open(ctx, obj, NULL, 0, NULL, 0,
                                                    format->offset, format->limit,
                                                    GRN_CURSOR_ASCENDING);
+      int resultset_size = -1;
       if (!tc) { ERRCLR(ctx); }
-      grn_output_array_open(ctx, outbuf, output_type, "RESULTSET", -1);
-      grn_output_array_open(ctx, outbuf, output_type, "NHITS", -1);
-      grn_text_itoa(ctx, outbuf, format->nhits);
+#ifdef HAVE_MESSAGE_PACK
+      resultset_size = 1; /* [NHITS, (COLUMNS), (HITS)] */
+      if (format->flags & GRN_OBJ_FORMAT_WITH_COLUMN_NAMES) {
+        resultset_size++;
+      }
+      resultset_size += format->limit;
+#endif
+      grn_output_array_open(ctx, outbuf, output_type, "RESULTSET", resultset_size);
+      grn_output_array_open(ctx, outbuf, output_type, "NHITS", 1);
+      if (output_type == GRN_CONTENT_XML) {
+        grn_text_itoa(ctx, outbuf, format->nhits);
+      } else {
+        grn_output_int32(ctx, outbuf, output_type, format->nhits);
+      }
       grn_output_array_close(ctx, outbuf, output_type);
       if (format->flags & GRN_OBJ_FORMAT_WITH_COLUMN_NAMES) {
-        grn_output_array_open(ctx, outbuf, output_type, "COLUMNS", -1);
+        grn_output_array_open(ctx, outbuf, output_type, "COLUMNS", ncolumns);
         for (j = 0; j < ncolumns; j++) {
           grn_id range_id;
-          grn_output_array_open(ctx, outbuf, output_type, "COLUMN", -1);
+          grn_output_array_open(ctx, outbuf, output_type, "COLUMN", 2);
           GRN_BULK_REWIND(&buf);
           grn_column_name_(ctx, columns[j], &buf);
           grn_output_obj(ctx, outbuf, output_type, &buf, NULL);
