@@ -1,5 +1,5 @@
 /* -*- c-basic-offset: 2 -*- */
-/* Copyright(C) 2009 Brazil
+/* Copyright(C) 2009-2012 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -1281,7 +1281,8 @@ grn_pat_get_value_(grn_ctx *ctx, grn_pat *pat, grn_id id, uint32_t *size)
 }
 
 grn_rc
-grn_pat_set_value(grn_ctx *ctx, grn_pat *pat, grn_id id, void *value, int flags)
+grn_pat_set_value(grn_ctx *ctx, grn_pat *pat, grn_id id,
+                  const void *value, int flags)
 {
   if (value) {
     uint32_t value_size = pat->value_size;
@@ -1330,8 +1331,8 @@ grn_pat_set_value(grn_ctx *ctx, grn_pat *pat, grn_id id, void *value, int flags)
 }
 
 grn_rc
-grn_pat_info(grn_ctx *ctx, grn_pat *pat, int *key_size, unsigned *flags,
-             grn_encoding *encoding, unsigned *n_entries, unsigned *file_size)
+grn_pat_info(grn_ctx *ctx, grn_pat *pat, int *key_size, unsigned int *flags,
+             grn_encoding *encoding, unsigned int *n_entries, unsigned int *file_size)
 {
   ERRCLR(NULL);
   if (!pat) { return GRN_INVALID_ARGUMENT; }
@@ -1345,7 +1346,7 @@ grn_pat_info(grn_ctx *ctx, grn_pat *pat, int *key_size, unsigned *flags,
     if ((rc = grn_io_size(ctx, pat->io, &tmp))) {
       return rc;
     }
-    *file_size = (unsigned) tmp; /* FIXME: inappropriate cast */
+    *file_size = (unsigned int) tmp; /* FIXME: inappropriate cast */
   }
   return GRN_SUCCESS;
 }
@@ -2187,7 +2188,8 @@ grn_pat_cursor_get_key_value(grn_ctx *ctx, grn_pat_cursor *c,
 }
 
 grn_rc
-grn_pat_cursor_set_value(grn_ctx *ctx, grn_pat_cursor *c, void *value, int flags)
+grn_pat_cursor_set_value(grn_ctx *ctx, grn_pat_cursor *c,
+                         const void *value, int flags)
 {
   return grn_pat_set_value(ctx, c->pat, c->curr_rec, value, flags);
 }
@@ -2205,7 +2207,7 @@ grn_pat_check(grn_ctx *ctx, grn_pat *pat)
   char buf[8];
   struct grn_pat_header *h = pat->header;
   GRN_OUTPUT_ARRAY_OPEN("RESULT", 1);
-  GRN_OUTPUT_MAP_OPEN("SUMMARY", 11);
+  GRN_OUTPUT_MAP_OPEN("SUMMARY", 22);
   GRN_OUTPUT_CSTR("flags");
   grn_itoh(h->flags, buf, 8);
   GRN_OUTPUT_STR(buf, 8);
@@ -2236,13 +2238,13 @@ grn_pat_check(grn_ctx *ctx, grn_pat *pat)
 static void
 grn_pat_inspect_check(grn_ctx *ctx, grn_obj *buf, int check)
 {
-    GRN_TEXT_PUTS(ctx, buf, "{");
-    grn_text_lltoa(ctx, buf, check >> 4);
-    GRN_TEXT_PUTS(ctx, buf, ",");
-    grn_text_lltoa(ctx, buf, (check >> 1) & 7);
-    GRN_TEXT_PUTS(ctx, buf, ",");
-    grn_text_lltoa(ctx, buf, check & 1);
-    GRN_TEXT_PUTS(ctx, buf, "}");
+  GRN_TEXT_PUTS(ctx, buf, "{");
+  grn_text_lltoa(ctx, buf, check >> 4);
+  GRN_TEXT_PUTS(ctx, buf, ",");
+  grn_text_lltoa(ctx, buf, (check >> 1) & 7);
+  GRN_TEXT_PUTS(ctx, buf, ",");
+  grn_text_lltoa(ctx, buf, check & 1);
+  GRN_TEXT_PUTS(ctx, buf, "}");
 }
 
 static void
