@@ -270,12 +270,23 @@ grn_plugin_register_by_path(grn_ctx *ctx, const char *path)
     grn_id id = GRN_ID_NIL;
     FILE *plugin_file;
     char complemented_path[PATH_MAX], complemented_libs_path[PATH_MAX];
+    size_t path_len;
 
+    if ((path_len = strlen(path)) >= PATH_MAX) {
+      ERR(GRN_FILENAME_TOO_LONG, "too long plugin path: <%s>", path);
+      goto exit;
+    }
     plugin_file = fopen(path, "r");
     if (plugin_file) {
       fclose(plugin_file);
       id = grn_plugin_open(ctx, path);
     } else {
+      if ((path_len += strlen(grn_plugin_get_suffix())) >= PATH_MAX) {
+        ERR(GRN_FILENAME_TOO_LONG,
+            "too long plugin path: <%s%s>",
+            path, grn_plugin_get_suffix());
+        goto exit;
+      }
       strcpy(complemented_path, path);
       strcat(complemented_path, grn_plugin_get_suffix());
       plugin_file = fopen(complemented_path, "r");
@@ -290,6 +301,13 @@ grn_plugin_register_by_path(grn_ctx *ctx, const char *path)
 
         base_name = strrchr(path, '/');
         if (base_name) {
+          path_len = base_name - path + strlen("/.libs") + strlen(base_name);
+          if ((path_len += strlen(grn_plugin_get_suffix())) >= PATH_MAX) {
+            ERR(GRN_FILENAME_TOO_LONG,
+                "too long plugin path: <%.*s/.libs%s%s>",
+                base_name - path, path, base_name, grn_plugin_get_suffix());
+            goto exit;
+          }
           complemented_libs_path[0] = '\0';
           strncat(complemented_libs_path, path, base_name - path);
           strcat(complemented_libs_path, "/.libs");
@@ -323,6 +341,7 @@ grn_plugin_register_by_path(grn_ctx *ctx, const char *path)
   } else {
     ERR(GRN_INVALID_ARGUMENT, "invalid db assigned");
   }
+exit :
   GRN_API_RETURN(ctx->rc);
 }
 
@@ -363,7 +382,6 @@ grn_plugin_register(grn_ctx *ctx, const char *name)
   const char *plugins_dir;
   char dir_last_char;
   char path[PATH_MAX];
-  char normalized_name[PATH_MAX];
   int name_length, max_name_length;
 
   if (name[0] == '/') {
