@@ -1,5 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
-/* Copyright(C) 2009-2011 Brazil
+/*
+  Copyright(C) 2009-2012 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -97,7 +98,7 @@ substitute_query(grn_ctx *ctx, grn_obj *table, grn_obj *column,
 {
   grn_id id;
   grn_rc rc = GRN_END_OF_DATA;
-  if ((id = grn_table_get(ctx, table, (const void *)key, (unsigned)key_size))) {
+  if ((id = grn_table_get(ctx, table, (const void *)key, (unsigned int)key_size))) {
     if ((column->header.type == GRN_COLUMN_VAR_SIZE) &&
         ((column->header.flags & GRN_OBJ_COLUMN_TYPE_MASK) == GRN_OBJ_COLUMN_VECTOR)) {
       unsigned int i, n;
@@ -129,7 +130,7 @@ substitute_query(grn_ctx *ctx, grn_obj *table, grn_obj *column,
 
 static grn_rc
 expand_query(grn_ctx *ctx, grn_obj *table, grn_obj *column, grn_expr_flags flags,
-             const char *str, unsigned str_len, grn_obj *dest)
+             const char *str, unsigned int str_len, grn_obj *dest)
 {
   grn_obj buf;
   unsigned int len;
@@ -247,21 +248,21 @@ exit :
 #define DUMP_COLUMNS            "_id, _key, _value, *"
 
 grn_rc
-grn_select(grn_ctx *ctx, const char *table, unsigned table_len,
-           const char *match_columns, unsigned match_columns_len,
-           const char *query, unsigned query_len,
-           const char *filter, unsigned filter_len,
-           const char *scorer, unsigned scorer_len,
-           const char *sortby, unsigned sortby_len,
-           const char *output_columns, unsigned output_columns_len,
+grn_select(grn_ctx *ctx, const char *table, unsigned int table_len,
+           const char *match_columns, unsigned int match_columns_len,
+           const char *query, unsigned int query_len,
+           const char *filter, unsigned int filter_len,
+           const char *scorer, unsigned int scorer_len,
+           const char *sortby, unsigned int sortby_len,
+           const char *output_columns, unsigned int output_columns_len,
            int offset, int limit,
-           const char *drilldown, unsigned drilldown_len,
-           const char *drilldown_sortby, unsigned drilldown_sortby_len,
-           const char *drilldown_output_columns, unsigned drilldown_output_columns_len,
+           const char *drilldown, unsigned int drilldown_len,
+           const char *drilldown_sortby, unsigned int drilldown_sortby_len,
+           const char *drilldown_output_columns, unsigned int drilldown_output_columns_len,
            int drilldown_offset, int drilldown_limit,
-           const char *cache, unsigned cache_len,
-           const char *match_escalation_threshold, unsigned match_escalation_threshold_len,
-           const char *query_expansion, unsigned query_expansion_len)
+           const char *cache, unsigned int cache_len,
+           const char *match_escalation_threshold, unsigned int match_escalation_threshold_len,
+           const char *query_expansion, unsigned int query_expansion_len)
 {
   uint32_t nkeys, nhits;
   uint16_t cacheable = 1, taintable = 0;
@@ -558,9 +559,9 @@ proc_select(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
   int limit = GRN_TEXT_LEN(VAR(8))
     ? grn_atoi(GRN_TEXT_VALUE(VAR(8)), GRN_BULK_CURR(VAR(8)), NULL)
     : DEFAULT_LIMIT;
-  char *output_columns = GRN_TEXT_VALUE(VAR(6));
+  const char *output_columns = GRN_TEXT_VALUE(VAR(6));
   uint32_t output_columns_len = GRN_TEXT_LEN(VAR(6));
-  char *drilldown_output_columns = GRN_TEXT_VALUE(VAR(11));
+  const char *drilldown_output_columns = GRN_TEXT_VALUE(VAR(11));
   uint32_t drilldown_output_columns_len = GRN_TEXT_LEN(VAR(11));
   int drilldown_offset = GRN_TEXT_LEN(VAR(12))
     ? grn_atoi(GRN_TEXT_VALUE(VAR(12)), GRN_BULK_CURR(VAR(12)), NULL)
@@ -890,6 +891,45 @@ proc_table_remove(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_d
   return NULL;
 }
 
+static grn_obj *
+proc_table_rename(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
+{
+  grn_rc rc = GRN_SUCCESS;
+  grn_obj *table = NULL;
+  if (GRN_TEXT_LEN(VAR(0)) == 0) {
+    rc = GRN_INVALID_ARGUMENT;
+    ERR(rc, "[table][rename] table name isn't specified");
+    goto exit;
+  }
+  table = grn_ctx_get(ctx, GRN_TEXT_VALUE(VAR(0)), GRN_TEXT_LEN(VAR(0)));
+  if (!table) {
+    rc = GRN_INVALID_ARGUMENT;
+    ERR(rc,
+        "[table][rename] table isn't found: <%.*s>",
+        GRN_TEXT_LEN(VAR(0)), GRN_TEXT_VALUE(VAR(0)));
+    goto exit;
+  }
+  if (GRN_TEXT_LEN(VAR(1)) == 0) {
+    rc = GRN_INVALID_ARGUMENT;
+    ERR(rc,
+        "[table][rename] new table name isn't specified: <%.*s>",
+        GRN_TEXT_LEN(VAR(0)), GRN_TEXT_VALUE(VAR(0)));
+    goto exit;
+  }
+  rc = grn_table_rename(ctx, table,
+                        GRN_TEXT_VALUE(VAR(1)), GRN_TEXT_LEN(VAR(1)));
+  if (rc != GRN_SUCCESS && ctx->rc == GRN_SUCCESS) {
+    ERR(rc,
+        "[table][rename] failed to rename: <%.*s> -> <%.*s>",
+        GRN_TEXT_LEN(VAR(0)), GRN_TEXT_VALUE(VAR(0)),
+        GRN_TEXT_LEN(VAR(1)), GRN_TEXT_VALUE(VAR(1)));
+  }
+exit:
+  GRN_OUTPUT_BOOL(!rc);
+  if (table) { grn_obj_unlink(ctx, table); }
+  return NULL;
+}
+
 static grn_obj *
 proc_column_create(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
 {
@@ -969,7 +1009,7 @@ proc_column_remove(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_
 {
   grn_obj *table, *col;
   char *colname,fullname[GRN_TABLE_MAX_KEY_SIZE];
-  unsigned colname_len,fullname_len;
+  unsigned int colname_len,fullname_len;
 
   table = grn_ctx_get(ctx, GRN_TEXT_VALUE(VAR(0)),
                            GRN_TEXT_LEN(VAR(0)));
@@ -995,6 +1035,66 @@ proc_column_remove(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_
   return NULL;
 }
 
+static grn_obj *
+proc_column_rename(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
+{
+  grn_rc rc = GRN_SUCCESS;
+  grn_obj *table = NULL;
+  grn_obj *column = NULL;
+  if (GRN_TEXT_LEN(VAR(0)) == 0) {
+    rc = GRN_INVALID_ARGUMENT;
+    ERR(rc, "[column][rename] table name isn't specified");
+    goto exit;
+  }
+  table = grn_ctx_get(ctx, GRN_TEXT_VALUE(VAR(0)), GRN_TEXT_LEN(VAR(0)));
+  if (!table) {
+    rc = GRN_INVALID_ARGUMENT;
+    ERR(rc,
+        "[column][rename] table isn't found: <%.*s>",
+        GRN_TEXT_LEN(VAR(0)), GRN_TEXT_VALUE(VAR(0)));
+    goto exit;
+  }
+  if (GRN_TEXT_LEN(VAR(1)) == 0) {
+    rc = GRN_INVALID_ARGUMENT;
+    ERR(rc,
+        "[column][rename] column name isn't specified: <%.*s>",
+        GRN_TEXT_LEN(VAR(0)), GRN_TEXT_VALUE(VAR(0)));
+    goto exit;
+  }
+  column = grn_obj_column(ctx, table,
+                          GRN_TEXT_VALUE(VAR(1)), GRN_TEXT_LEN(VAR(1)));
+  if (!column) {
+    rc = GRN_INVALID_ARGUMENT;
+    ERR(rc,
+        "[column][rename] column isn't found: <%.*s.%.*s>",
+        GRN_TEXT_LEN(VAR(0)), GRN_TEXT_VALUE(VAR(0)),
+        GRN_TEXT_LEN(VAR(1)), GRN_TEXT_VALUE(VAR(1)));
+    goto exit;
+  }
+  if (GRN_TEXT_LEN(VAR(2)) == 0) {
+    rc = GRN_INVALID_ARGUMENT;
+    ERR(rc,
+        "[column][rename] new column name isn't specified: <%.*s.%.*s>",
+        GRN_TEXT_LEN(VAR(0)), GRN_TEXT_VALUE(VAR(0)),
+        GRN_TEXT_LEN(VAR(1)), GRN_TEXT_VALUE(VAR(1)));
+    goto exit;
+  }
+  rc = grn_column_rename(ctx, column,
+                         GRN_TEXT_VALUE(VAR(2)), GRN_TEXT_LEN(VAR(2)));
+  if (rc != GRN_SUCCESS && ctx->rc == GRN_SUCCESS) {
+    ERR(rc,
+        "[column][rename] failed to rename: <%.*s.%.*s> -> <%.*s.%.*s>",
+        GRN_TEXT_LEN(VAR(0)), GRN_TEXT_VALUE(VAR(0)),
+        GRN_TEXT_LEN(VAR(1)), GRN_TEXT_VALUE(VAR(1)),
+        GRN_TEXT_LEN(VAR(0)), GRN_TEXT_VALUE(VAR(0)),
+        GRN_TEXT_LEN(VAR(2)), GRN_TEXT_VALUE(VAR(2)));
+  }
+exit:
+  GRN_OUTPUT_BOOL(!rc);
+  if (column) { grn_obj_unlink(ctx, column); }
+  if (table) { grn_obj_unlink(ctx, table); }
+  return NULL;
+}
 
 #define GRN_STRLEN(s) ((s) ? strlen(s) : 0)
 
@@ -1030,7 +1130,7 @@ print_columninfo(grn_ctx *ctx, grn_obj *column)
 {
   grn_obj o;
   grn_id id;
-  char *type;
+  const char *type;
   const char *path;
 
   switch (column->header.type) {
@@ -1648,7 +1748,7 @@ proc_delete(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
     } else if (GRN_TEXT_LEN(VAR(3))) {
       grn_obj *cond, *v;
       const char *filter = GRN_TEXT_VALUE(VAR(3));
-      unsigned filter_len = GRN_TEXT_LEN(VAR(3));
+      unsigned int filter_len = GRN_TEXT_LEN(VAR(3));
 
       GRN_EXPR_CREATE_FOR_QUERY(ctx, table, cond, v);
       grn_expr_parse(ctx, cond, filter, filter_len,
@@ -2689,6 +2789,10 @@ grn_db_init_builtin_query(grn_ctx *ctx)
   DEF_VAR(vars[0], "name");
   DEF_COMMAND("table_remove", proc_table_remove, 1, vars);
 
+  DEF_VAR(vars[0], "name");
+  DEF_VAR(vars[1], "new_name");
+  DEF_COMMAND("table_rename", proc_table_rename, 2, vars);
+
   DEF_VAR(vars[0], "table");
   DEF_VAR(vars[1], "name");
   DEF_VAR(vars[2], "flags");
@@ -2700,6 +2804,11 @@ grn_db_init_builtin_query(grn_ctx *ctx)
   DEF_VAR(vars[1], "name");
   DEF_COMMAND("column_remove", proc_column_remove, 2, vars);
 
+  DEF_VAR(vars[0], "table");
+  DEF_VAR(vars[1], "name");
+  DEF_VAR(vars[2], "new_name");
+  DEF_COMMAND("column_rename", proc_column_rename, 3, vars);
+
   DEF_VAR(vars[0], "path");
   DEF_COMMAND(GRN_EXPR_MISSING_NAME, proc_missing, 1, vars);
 
