@@ -1,5 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
-/* Copyright(C) 2009 Brazil
+/*
+  Copyright(C) 2009-2012 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -687,7 +688,7 @@ grn_ql_mk_symbol2(grn_ctx *ctx, const char *q, unsigned int len, int kwdp)
 }
 
 static grn_cell *
-str2num(grn_ctx *ctx, char *str, unsigned int len)
+str2num(grn_ctx *ctx, const char *str, unsigned int len)
 {
   const char *cur, *str_end = str + len;
   int64_t i = grn_atoll(str, str_end, &cur);
@@ -1897,7 +1898,7 @@ opexe(grn_ctx *ctx)
   case OP_RDSEXPR:
     {
       char tok, *str;
-      unsigned len;
+      unsigned int len;
       RTN_NIL_IF_HEAD(ctx);
       switch (ctx->impl->tok) {
       case TOK_COMMENT:
@@ -1957,7 +1958,7 @@ opexe(grn_ctx *ctx)
           o->header.type = GRN_CELL_STR;
           o->header.impl_flags = 0;
           o->u.b.size = 1;
-          o->u.b.value = "?";
+          o->u.b.value = (char *)"?";
           *ctx->impl->pht = p;
           ctx->impl->pht = &CDR(p);
           s_return(ctx, o);
@@ -1980,7 +1981,7 @@ opexe(grn_ctx *ctx)
       grn_cell *v = non_alloc_rev(NIL, ctx->impl->args);
       if (ctx->impl->cur < ctx->impl->str_end && *ctx->impl->cur == '.') {
         char *str = NULL;
-        unsigned len = 0;
+        unsigned int len = 0;
         if (readstr(ctx, &str, &len) != TOK_ATOM) { /* error */ }
         s_return(ctx, mk_atom(ctx, str, len, v));
       } else {
@@ -2006,7 +2007,7 @@ opexe(grn_ctx *ctx)
       grn_cell *v = non_alloc_rev(ctx->impl->value, ctx->impl->args);
       if (ctx->impl->cur < ctx->impl->str_end && *ctx->impl->cur == '.') {
         char *str = NULL;
-        unsigned len = 0;
+        unsigned int len = 0;
         if (readstr(ctx, &str, &len) != TOK_ATOM) { /* error */ }
         s_return(ctx, mk_atom(ctx, str, len, v));
       } else {
@@ -3332,7 +3333,7 @@ nf_geo_withinp(grn_ctx *ctx, grn_cell *args, grn_ql_co *co)
 /* ========== Initialization of internal keywords ========== */
 
 inline static void
-mk_syntax(grn_ctx *ctx, uint8_t op, char *name)
+mk_syntax(grn_ctx *ctx, uint8_t op, const char *name)
 {
   grn_cell *x;
   if ((x = INTERN(name)) != F) {
@@ -3342,7 +3343,7 @@ mk_syntax(grn_ctx *ctx, uint8_t op, char *name)
 }
 
 inline static void
-mk_proc(grn_ctx *ctx, uint8_t op, char *name)
+mk_proc(grn_ctx *ctx, uint8_t op, const char *name)
 {
   grn_cell *x;
   if ((x = INTERN(name)) != F) {
