@@ -1,5 +1,5 @@
 /* -*- c-basic-offset: 2 -*- */
-/* Copyright(C) 2009-2010 Brazil
+/* Copyright(C) 2009-2011 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -29,34 +29,56 @@
 #include <string.h>
 #include <ctype.h>
 
-static mecab_t *sole_mecab;
+static mecab_t *sole_mecab = NULL;
 static grn_critical_section sole_mecab_lock;
-
-#define SOLE_MECAB_CONFIRM do {\
-  if (!sole_mecab) {\
-    static char *argv[] = {"", "-Owakati"};\
-    CRITICAL_SECTION_ENTER(sole_mecab_lock);\
-    if (!sole_mecab) {\
-      sole_mecab = mecab_new(2, argv);\
-      if (!sole_mecab) {\
-        strncpy(mecab_err, mecab_strerror(NULL), sizeof(mecab_err) - 1);\
-      }\
-    }\
-    CRITICAL_SECTION_LEAVE(sole_mecab_lock);\
-  }\
-} while(0)
+static grn_encoding sole_mecab_encoding = GRN_ENC_NONE;
 
 typedef struct {
   grn_str *nstr;
   mecab_t *mecab;
-  unsigned char *buf;
-  unsigned char *next;
-  unsigned char *end;
+  char *buf;
+  char *next;
+  char *end;
   grn_encoding encoding;
   grn_obj curr_;
   grn_obj stat_;
 } grn_mecab_tokenizer;
 
+static grn_encoding
+translate_mecab_charset_to_grn_encoding(const char *charset)
+{
+  if (strcasecmp(charset, "euc-jp") == 0) {
+    return GRN_ENC_EUC_JP;
+  } else if (strcasecmp(charset, "utf-8") == 0 ||
+             strcasecmp(charset, "utf8") == 0) {
+    return GRN_ENC_UTF8;
+  } else if (strcasecmp(charset, "shift_jis") == 0 ||
+             strcasecmp(charset, "shift-jis") == 0 ||
+             strcasecmp(charset, "sjis") == 0) {
+    return GRN_ENC_SJIS;
+  }
+  return GRN_ENC_NONE;
+}
+
+static grn_encoding
+get_mecab_encoding(mecab_t *mecab)
+{
+  grn_encoding encoding = GRN_ENC_NONE;
+  const mecab_dictionary_info_t *dictionary_info;
+  dictionary_info = mecab_dictionary_info(mecab);
+  if (dictionary_info) {
+    const char *charset = dictionary_info->charset;
+    encoding = translate_mecab_charset_to_grn_encoding(charset);
+  }
+  return encoding;
+}
+
+/*
+  This function is called for a full text search query or a document to be
+  indexed. This means that both short/long strings are given.
+  The return value of this function is ignored. When an error occurs in this
+  function, `ctx->rc' is overwritten with an error code (not GRN_SUCCESS).
+ */
 static grn_obj *
 mecab_init(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
 {
@@ -66,6 +88,7 @@ mecab_init(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
   char mecab_err[256];
   grn_obj *table = args[0];
   grn_obj_flags table_flags;
+  grn_encoding table_encoding;
   grn_mecab_tokenizer *token;
   unsigned int bufsize, maxtrial = 10, len;
   if (!(str = grn_ctx_pop(ctx))) {
@@ -73,17 +96,33 @@ mecab_init(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
     return NULL;
   }
   mecab_err[sizeof(mecab_err) - 1] = '\0';
-  SOLE_MECAB_CONFIRM;
+  if (!sole_mecab) {
+    CRITICAL_SECTION_ENTER(sole_mecab_lock);
+    if (!sole_mecab) {
+      sole_mecab = mecab_new2("-Owakati");
+      if (!sole_mecab) {
+        strncpy(mecab_err, mecab_strerror(NULL), sizeof(mecab_err) - 1);
+      } else {
+        sole_mecab_encoding = get_mecab_encoding(sole_mecab);
+      }
+    }
+    CRITICAL_SECTION_LEAVE(sole_mecab_lock);
+  }
   if (!sole_mecab) {
     ERR(GRN_TOKENIZER_ERROR,
-        "mecab_new failed on grn_mecab_init: %s", mecab_err);
+        "mecab_new2 failed on grn_mecab_init: %s", mecab_err);
+    return NULL;
+  }
+  grn_table_get_info(ctx, table, &table_flags, &table_encoding, NULL);
+  if (table_encoding != sole_mecab_encoding) {
+    ERR(GRN_TOKENIZER_ERROR,
+        "MeCab dictionary charset (%s) does not match the context encoding: <%s>",
+        grn_enctostr(sole_mecab_encoding), grn_enctostr(table_encoding));
     return NULL;
   }
   if (!(token = GRN_MALLOC(sizeof(grn_mecab_tokenizer)))) { return NULL; }
-  user_data->ptr = token;
   token->mecab = sole_mecab;
-  // if (!(token->mecab = mecab_new3())) {
-  grn_table_get_info(ctx, table, &table_flags, &token->encoding, NULL);
+  token->encoding = table_encoding;
   nflags |= (table_flags & GRN_OBJ_KEY_NORMALIZE);
   if (!(token->nstr = grn_str_open_(ctx, GRN_TEXT_VALUE(str), GRN_TEXT_LEN(str),
                                     nflags, token->encoding))) {
@@ -93,8 +132,9 @@ mecab_init(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
   }
   len = token->nstr->norm_blen;
   for (bufsize = len * 2 + 1; maxtrial; bufsize *= 2, maxtrial--) {
-    if(!(buf = GRN_MALLOC(bufsize + 1))) {
+    if (!(buf = GRN_MALLOC(bufsize + 1))) {
       GRN_LOG(ctx, GRN_LOG_ALERT, "buffer allocation on mecab_init failed !");
+      grn_str_close(ctx, token->nstr);
       GRN_FREE(token);
       return NULL;
     }
@@ -110,40 +150,45 @@ mecab_init(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
   }
   if (!s) {
     ERR(GRN_TOKENIZER_ERROR, "mecab_sparse_tostr failed len=%d bufsize=%d err=%s",
-            len, bufsize, mecab_err);
+        len, bufsize, mecab_err);
+    grn_str_close(ctx, token->nstr);
     GRN_FREE(token);
     return NULL;
   }
-  // certain version of mecab returns trailing lf or spaces.
+  /* A certain version of mecab returns trailing lf or spaces. */
   for (p = buf + strlen(buf) - 1;
-       buf <= p && (*p == '\n' || isspace(*(unsigned char *)p));
+       buf <= p && isspace(*(unsigned char *)p);
        p--) { *p = '\0'; }
-  //grn_log("sparsed='%s'", s);
-  token->buf = (unsigned char *)buf;
-  token->next = (unsigned char *)buf;
-  token->end = (unsigned char *)buf + strlen(buf);
+  /* grn_log("sparsed='%s'", s); */
+  user_data->ptr = token;
+  token->buf = buf;
+  token->next = buf;
+  token->end = buf + strlen(buf);
   GRN_TEXT_INIT(&token->curr_, GRN_OBJ_DO_SHALLOW_COPY);
   GRN_UINT32_INIT(&token->stat_, 0);
   return NULL;
 }
 
+/*
+  This function returns tokens one by one.
+ */
 static grn_obj *
 mecab_next(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
 {
   size_t cl;
-  //  grn_obj *table = args[0];
+  /* grn_obj *table = args[0]; */
   grn_mecab_tokenizer *token = user_data->ptr;
-  const unsigned char *p = token->next, *r;
-  const unsigned char *e = token->end;
+  char *p = token->next, *r;
+  char *e = token->end;
   for (r = p; r < e; r += cl) {
-    if (!(cl = grn_charlen_(ctx, (char *)r, (char *)e, token->encoding))) {
-      token->next = (unsigned char *)e;
+    if (!(cl = grn_charlen_(ctx, r, e, token->encoding))) {
+      token->next = e;
       break;
     }
-    if (grn_isspace((const char *)r, token->encoding)) {
-      const unsigned char *q = r;
-      while ((cl = grn_isspace((const char *)q, token->encoding))) { q += cl; }
-      token->next = (unsigned char *)q;
+    if (grn_isspace(r, token->encoding)) {
+      char *q = r;
+      while ((cl = grn_isspace(q, token->encoding))) { q += cl; }
+      token->next = q;
       break;
     }
   }
@@ -154,12 +199,13 @@ mecab_next(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
   return NULL;
 }
 
+/*
+  This function finalizes a tokenization.
+ */
 static grn_obj *
 mecab_fin(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
 {
-  //  grn_obj *table = args[0];
   grn_mecab_tokenizer *token = user_data->ptr;
-  // if (token->mecab) { mecab_destroy(token->mecab); }
   grn_str_close(ctx, token->nstr);
   GRN_FREE(token->buf);
   GRN_FREE(token);
@@ -172,38 +218,13 @@ check_mecab_dictionary_encoding(grn_ctx *ctx)
 #ifdef HAVE_MECAB_DICTIONARY_INFO_T
   mecab_t *mecab;
 
-  mecab = mecab_new(0, NULL);
+  mecab = mecab_new2("-Owakati");
   if (mecab) {
     grn_encoding encoding;
-    const mecab_dictionary_info_t *dictionary;
     int have_same_encoding_dictionary = 0;
 
     encoding = GRN_CTX_GET_ENCODING(ctx);
-    dictionary = mecab_dictionary_info(mecab);
-    for (; dictionary; dictionary = dictionary->next) {
-      switch (encoding) {
-      case GRN_ENC_EUC_JP:
-        if (strcasecmp(dictionary->charset, "euc-jp") == 0) {
-          have_same_encoding_dictionary = 1;
-        }
-        break;
-      case GRN_ENC_UTF8:
-        if (strcasecmp(dictionary->charset, "utf-8") == 0 ||
-            strcasecmp(dictionary->charset, "utf8") == 0) {
-          have_same_encoding_dictionary = 1;
-        }
-        break;
-      case GRN_ENC_SJIS:
-        if (strcasecmp(dictionary->charset, "shift_jis") == 0 ||
-            strcasecmp(dictionary->charset, "shift-jis") == 0 ||
-            strcasecmp(dictionary->charset, "sjis") == 0) {
-          have_same_encoding_dictionary = 1;
-        }
-        break;
-      default:
-        break;
-      }
-    }
+    have_same_encoding_dictionary = encoding == get_mecab_encoding(mecab);
     mecab_destroy(mecab);
 
     if (!have_same_encoding_dictionary) {
@@ -211,10 +232,17 @@ check_mecab_dictionary_encoding(grn_ctx *ctx)
           "MeCab has no dictionary that uses the context encoding: <%s>",
           grn_enctostr(encoding));
     }
+  } else {
+    ERR(GRN_TOKENIZER_ERROR,
+        "mecab_new2 failed in check_mecab_dictionary_encoding");
   }
 #endif
 }
 
+/*
+  This function initializes a plugin. This function fails if there is no
+  dictionary that uses the context encoding of groonga.
+ */
 grn_rc
 GRN_PLUGIN_INIT(grn_ctx *ctx)
 {
@@ -222,10 +250,12 @@ GRN_PLUGIN_INIT(grn_ctx *ctx)
   CRITICAL_SECTION_INIT(sole_mecab_lock);
 
   check_mecab_dictionary_encoding(ctx);
-
-  return GRN_SUCCESS;
+  return ctx->rc;
 }
 
+/*
+  This function registers a plugin to a database.
+ */
 grn_rc
 GRN_PLUGIN_REGISTER(grn_ctx *ctx)
 {
@@ -239,6 +269,10 @@ GRN_PLUGIN_REGISTER(grn_ctx *ctx)
   GRN_TEXT_INIT(&vars[1].value, 0);
   GRN_UINT32_INIT(&vars[2].value, 0);
 
+  /*
+    grn_proc_create() registers a plugin to a database which is associated
+    with `ctx'. A returned object must not be finalized here.
+   */
   obj = grn_proc_create(ctx, "TokenMecab", 10, GRN_PROC_TOKENIZER,
                         mecab_init, mecab_next, mecab_fin, 3, vars);
   if (!obj || ((grn_db_obj *)obj)->id != GRN_DB_MECAB) { return GRN_FILE_CORRUPT; }
@@ -246,6 +280,9 @@ GRN_PLUGIN_REGISTER(grn_ctx *ctx)
   return GRN_SUCCESS;
 }
 
+/*
+  This function finalizes a plugin.
+ */
 grn_rc
 GRN_PLUGIN_FIN(grn_ctx *ctx)
 {
