@@ -1,5 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
-/* Copyright(C) 2009-2011 Brazil
+/*
+  Copyright(C) 2009-2012 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -546,14 +547,9 @@ print_return_code(grn_ctx *ctx, grn_rc rc, grn_obj *head, grn_obj *body, grn_obj
         grn_text_esc(ctx, head, ctx->errfile, strlen(ctx->errfile));
         GRN_TEXT_PUTC(ctx, head, ',');
         grn_text_itoa(ctx, head, ctx->errline);
-        if ((command = GRN_CTX_USER_DATA(ctx)->ptr)) {
+        if (input_path && (command = GRN_CTX_USER_DATA(ctx)->ptr)) {
           GRN_TEXT_PUTC(ctx, head, ',');
-          if (input_path) {
-            grn_text_esc(ctx, head, input_path, strlen(input_path));
-          } else {
-            const char *stdin_name = "(stdin)";
-            grn_text_esc(ctx, head, stdin_name, strlen(stdin_name));
-          }
+          grn_text_esc(ctx, head, input_path, strlen(input_path));
           GRN_TEXT_PUTC(ctx, head, ',');
           grn_text_itoa(ctx, head, number_of_lines);
           GRN_TEXT_PUTC(ctx, head, ',');
@@ -612,7 +608,7 @@ print_return_code(grn_ctx *ctx, grn_rc rc, grn_obj *head, grn_obj *body, grn_obj
         grn_text_ftoa(ctx, head, started);
         GRN_TEXT_PUTS(ctx, head, "\" ELAPSED=\"");
         grn_text_ftoa(ctx, head, elapsed);
-        GRN_TEXT_PUTS(ctx, head, "\">");
+        GRN_TEXT_PUTS(ctx, head, "\">\n");
         if (rc != GRN_SUCCESS) {
           GRN_TEXT_PUTS(ctx, head, "<ERROR>");
           grn_text_escape_xml(ctx, head, ctx->errbuf, strlen(ctx->errbuf));
@@ -628,7 +624,7 @@ print_return_code(grn_ctx *ctx, grn_rc rc, grn_obj *head, grn_obj *body, grn_obj
           }
           GRN_TEXT_PUTS(ctx, head, "</ERROR>");
         }
-        GRN_TEXT_PUTS(ctx, foot, "</RESULT>");
+        GRN_TEXT_PUTS(ctx, foot, "\n</RESULT>");
       }
     }
     break;
@@ -815,7 +811,7 @@ g_client(int argc, char **argv)
 {
   int rc = -1;
   grn_ctx ctx_, *ctx = &ctx_;
-  char *hostname = DEFAULT_DEST;
+  const char *hostname = DEFAULT_DEST;
   if (argc > 0 && argv) { hostname = *argv++; argc--; }
   grn_ctx_init(ctx, (batchmode ? GRN_CTX_BATCH_MODE : 0));
   if (!grn_ctx_connect(ctx, hostname, port, 0)) {
