@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2; coding: utf-8 -*- */
 /*
-  Copyright (C) 2011  Brazil
+  Copyright (C) 2011-2012  Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -35,6 +35,14 @@
 
 namespace
 {
+  void enter_api(grn_ctx *ctx) {
+    GRN_API_ENTER
+  }
+
+  int leave_api(grn_ctx *ctx) {
+    GRN_API_RETURN(0);
+  }
+
   void create_key(std::string *key, std::size_t min_length, std::size_t max_length)
   {
     key->resize(min_length + (std::rand() % (max_length - min_length + 1)));
@@ -57,6 +65,8 @@ namespace
   }
 }
 
+#define ENABLE_API APIScope api_scope(&ctx);
+
 namespace test_dat
 {
   const char *base_dir;
@@ -71,10 +81,12 @@ namespace test_dat
     g_mkdir_with_parents(base_dir, 0755);
 
     grn_ctx_init(&ctx, 0);
+    enter_api(&ctx);
   }
 
   void cut_teardown(void)
   {
+    leave_api(&ctx);
     grn_ctx_fin(&ctx);
 
     if (base_dir) {
@@ -82,15 +94,18 @@ namespace test_dat
     }
   }
 
-  grn_dat *create_trie(const std::vector<std::string> &keys, const char *path) {
-    grn_dat * const dat = grn_dat_create(&ctx, path, 0, 0, GRN_OBJ_KEY_VAR_SIZE);
-    cut_assert_not_null(dat);
+  grn_dat *create_trie(const std::vector<std::string> &keys, const char *path,
+                       unsigned int flags = 0) {
+    flags |= GRN_OBJ_KEY_VAR_SIZE;
+    grn_dat * const dat = grn_dat_create(&ctx, path, 0, 0, flags);
+    cppcut_assert_not_null(dat);
     for (std::size_t i = 0; i < keys.size(); ++i) {
       const char * const ptr = keys[i].c_str();
       const uint32_t length = static_cast<uint32_t>(keys[i].length());
       int added;
       const grn_id key_id = grn_dat_add(&ctx, dat, ptr, length, NULL, &added);
-      cut_assert(key_id != GRN_ID_NIL);
+      cppcut_assert_not_equal(static_cast<const grn_id>(GRN_ID_NIL),
+                              key_id);
       cut_assert_true(added);
     }
     return dat;
@@ -130,7 +145,7 @@ namespace test_dat
 
     grn_dat * const dat = create_trie(keys, dat_path);
     grn_dat * const dat2 = grn_dat_open(&ctx, dat_path);
-    cut_assert_not_null(dat2);
+    cppcut_assert_not_null(dat2);
     for (std::size_t i = 0; i < keys.size(); ++i) {
       const char * const ptr = keys[i].c_str();
       const uint32_t length = static_cast<uint32_t>(keys[i].length());
@@ -140,8 +155,8 @@ namespace test_dat
     cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
     cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat2));
 
-    cut_assert_null(grn_dat_open(&ctx, NULL));
-    cut_assert_null(grn_dat_open(&ctx, ""));
+    cppcut_assert_null(grn_dat_open(&ctx, NULL));
+    cppcut_assert_null(grn_dat_open(&ctx, ""));
   }
 
   void test_remove(void)
@@ -149,11 +164,20 @@ namespace test_dat
     char dat_path[PATH_MAX];
     std::sprintf(dat_path, "%s/%s", base_dir, "test_remove.tmp");
 
+    cppcut_assert_equal(GRN_NO_SUCH_FILE_OR_DIRECTORY,
+                        grn_dat_remove(&ctx, dat_path));
+    cppcut_assert_equal(GRN_NO_SUCH_FILE_OR_DIRECTORY, ctx.rc);
+    ctx.rc = GRN_SUCCESS;
+
     std::vector<std::string> keys;
     create_keys(&keys, 1000, 6, 15);
 
     grn_dat * const dat = create_trie(keys, dat_path);
+    cppcut_assert_equal(GRN_SUCCESS, grn_dat_repair(&ctx, dat));
+    cppcut_assert_equal(GRN_SUCCESS, grn_dat_repair(&ctx, dat));
+    cppcut_assert_equal(GRN_SUCCESS, grn_dat_repair(&ctx, dat));
     const uint32_t last_file_id = dat->file_id;
+    cppcut_assert_equal(static_cast<uint32_t>(4), last_file_id);
     cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
 
     cppcut_assert_equal(GRN_SUCCESS, grn_dat_remove(&ctx, dat_path));
@@ -163,6 +187,7 @@ namespace test_dat
       std::sprintf(trie_path, "%s.%03d", dat_path, i);
       cut_assert_not_exist_path(trie_path);
     }
+    cppcut_assert_equal(GRN_SUCCESS, ctx.rc);
 
     cppcut_assert_equal(GRN_INVALID_ARGUMENT, grn_dat_remove(&ctx, NULL));
   }
@@ -225,7 +250,7 @@ namespace test_dat
 
       uint32_t key_length;
       const char * const key_ptr = _grn_dat_key(&ctx, dat, key_id, &key_length);
-      cut_assert_not_null(key_ptr);
+      cppcut_assert_not_null(key_ptr);
       cppcut_assert_equal(length, static_cast<int>(key_length));
 
       cppcut_assert_equal(length, grn_dat_get_key2(&ctx, dat, key_id, &bulk));
@@ -253,7 +278,7 @@ namespace test_dat
 
       uint32_t key_length;
       const char * const key_ptr = _grn_dat_key(&ctx, dat, key_id, &key_length);
-      cut_assert_not_null(key_ptr);
+      cppcut_assert_not_null(key_ptr);
       cppcut_assert_equal(length, static_cast<int>(key_length));
 
       GRN_BULK_REWIND(&bulk);
@@ -337,7 +362,7 @@ namespace test_dat
     create_keys(&keys, 1000, 6, 15);
 
     grn_dat * const dat = grn_dat_create(&ctx, NULL, 0, 0, GRN_OBJ_KEY_VAR_SIZE);
-    cut_assert_not_null(dat);
+    cppcut_assert_not_null(dat);
     for (std::size_t i = 0; i < (keys.size() / 2); ++i) {
       const char * const ptr = keys[i].c_str();
       const uint32_t length = static_cast<uint32_t>(keys[i].length());
@@ -383,7 +408,7 @@ namespace test_dat
     create_keys(&keys, 1000, 6, 15);
 
     grn_dat * const dat = grn_dat_create(&ctx, NULL, 0, 0, GRN_OBJ_KEY_VAR_SIZE);
-    cut_assert_not_null(dat);
+    cppcut_assert_not_null(dat);
     for (std::size_t i = 0; i < (keys.size() / 2); ++i) {
       const char * const ptr = keys[i].c_str();
       const uint32_t length = static_cast<uint32_t>(keys[i].length());
@@ -423,6 +448,114 @@ namespace test_dat
     cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
 
+  void test_scan(void)
+  {
+    {
+      std::vector<std::string> keys;
+      keys.push_back("12");
+      keys.push_back("234");
+      keys.push_back("45");
+      keys.push_back("789");
+
+      const char text[] = "0123456789X";
+      const unsigned int text_size = sizeof(text) - 1;
+      grn_dat_scan_hit scan_hits[4];
+      const unsigned int max_num_scan_hits = sizeof(scan_hits) / sizeof(scan_hits[0]);
+
+      grn_dat * const dat = create_trie(keys, NULL);
+
+      const char *text_rest;
+      cppcut_assert_equal(3,
+                          grn_dat_scan(&ctx, dat, text, text_size,
+                          scan_hits, max_num_scan_hits, &text_rest));
+      cppcut_assert_equal(text + text_size, text_rest);
+      cppcut_assert_equal(static_cast<grn_id>(1), scan_hits[0].id);
+      cppcut_assert_equal(1U, scan_hits[0].offset);
+      cppcut_assert_equal(2U, scan_hits[0].length);
+      cppcut_assert_equal(static_cast<grn_id>(3), scan_hits[1].id);
+      cppcut_assert_equal(4U, scan_hits[1].offset);
+      cppcut_assert_equal(2U, scan_hits[1].length);
+      cppcut_assert_equal(static_cast<grn_id>(4), scan_hits[2].id);
+      cppcut_assert_equal(7U, scan_hits[2].offset);
+      cppcut_assert_equal(3U, scan_hits[2].length);
+
+      cppcut_assert_equal(1,
+                          grn_dat_scan(&ctx, dat, text, text_size,
+                                       scan_hits, 1, &text_rest));
+      cppcut_assert_equal(static_cast<std::ptrdiff_t>(3), text_rest - text);
+      cppcut_assert_equal(1,
+                          grn_dat_scan(&ctx, dat, text_rest, text_size - (text_rest - text),
+                                       scan_hits, 1, &text_rest));
+      cppcut_assert_equal(static_cast<std::ptrdiff_t>(6), text_rest - text);
+      cppcut_assert_equal(1,
+                          grn_dat_scan(&ctx, dat, text_rest, text_size - (text_rest - text),
+                                       scan_hits, 1, &text_rest));
+      cppcut_assert_equal(static_cast<std::ptrdiff_t>(10), text_rest - text);
+      cppcut_assert_equal(0,
+                          grn_dat_scan(&ctx, dat, text_rest, text_size - (text_rest - text),
+                                       scan_hits, 1, &text_rest));
+
+      cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    }
+
+    {
+      std::vector<std::string> keys;
+      keys.push_back("ユニグラム");
+      keys.push_back("グラム");
+
+      const char text[] = "ユニ㌘…ハ゛イク゛ラム";
+      const unsigned int text_size = sizeof(text) - 1;
+      grn_dat_scan_hit scan_hits[4];
+      const unsigned int max_num_scan_hits = sizeof(scan_hits) / sizeof(scan_hits[0]);
+
+      grn_dat * const dat = create_trie(keys, NULL, GRN_OBJ_KEY_NORMALIZE);
+
+      const char *text_rest;
+      cppcut_assert_equal(2,
+                          grn_dat_scan(&ctx, dat, text, text_size,
+                          scan_hits, max_num_scan_hits, &text_rest));
+      cppcut_assert_equal(text + text_size, text_rest);
+      cppcut_assert_equal(static_cast<grn_id>(1), scan_hits[0].id);
+      cppcut_assert_equal(0U, scan_hits[0].offset);
+      cppcut_assert_equal(9U, scan_hits[0].length);
+      cppcut_assert_equal(static_cast<grn_id>(2), scan_hits[1].id);
+      cppcut_assert_equal(21U, scan_hits[1].offset);
+      cppcut_assert_equal(12U, scan_hits[1].length);
+
+      cppcut_assert_equal(1,
+                          grn_dat_scan(&ctx, dat, text, text_size,
+                                       scan_hits, 1, &text_rest));
+      cppcut_assert_equal(static_cast<std::ptrdiff_t>(9), text_rest - text);
+      cppcut_assert_equal(1,
+                          grn_dat_scan(&ctx, dat, text_rest, text_size - (text_rest - text),
+                                       scan_hits, 1, &text_rest));
+      cppcut_assert_equal(static_cast<std::ptrdiff_t>(33), text_rest - text);
+      cppcut_assert_equal(0,
+                          grn_dat_scan(&ctx, dat, text_rest, text_size - (text_rest - text),
+                                       scan_hits, 1, &text_rest));
+
+      cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    }
+
+    {
+      std::vector<std::string> keys;
+      create_keys(&keys, 1000, 6, 15);
+
+      grn_dat * const dat = create_trie(keys, NULL);
+      for (std::size_t i = 0; i < keys.size(); ++i) {
+        const grn_id key_id = static_cast<grn_id>(i + 1);
+        const char * const ptr = keys[i].c_str();
+        const uint32_t length = static_cast<uint32_t>(keys[i].length());
+        grn_dat_scan_hit scan_hits[2];
+        cppcut_assert_equal(1, grn_dat_scan(&ctx, dat, ptr, length, scan_hits, 2, NULL));
+        cppcut_assert_equal(key_id, scan_hits[0].id);
+        cppcut_assert_equal(0U, scan_hits[0].offset);
+        cppcut_assert_equal(length, scan_hits[0].length);
+      }
+      cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    }
+  }
+
   void test_lcp_search(void)
   {
     {
@@ -478,7 +611,7 @@ namespace test_dat
   void test_curr_id(void)
   {
     grn_dat * const dat = grn_dat_create(&ctx, NULL, 0, 0, GRN_OBJ_KEY_VAR_SIZE);
-    cut_assert_not_null(dat);
+    cppcut_assert_not_null(dat);
 
     grn_id max_key_id = 0;
     std::string key;
@@ -496,10 +629,13 @@ namespace test_dat
 
   void test_truncate(void)
   {
+    char dat_path[PATH_MAX];
+    std::sprintf(dat_path, "%s/%s", base_dir, "test_truncate");
+
     std::vector<std::string> keys;
     create_keys(&keys, 1000, 6, 15);
 
-    grn_dat * const dat = create_trie(keys, NULL);
+    grn_dat * const dat = create_trie(keys, dat_path);
     cppcut_assert_equal(GRN_SUCCESS, grn_dat_truncate(&ctx, dat));
     cppcut_assert_equal(static_cast<unsigned int>(0), grn_dat_size(&ctx, dat));
     cppcut_assert_equal(static_cast<grn_id>(0), grn_dat_curr_id(&ctx, dat));
@@ -520,15 +656,14 @@ namespace test_dat
     grn_dat * const dat = create_trie(keys, NULL);
     for (std::size_t i = 0; i < keys.size(); ++i) {
       const grn_id key_id = static_cast<grn_id>(i + 1);
-      const char * const ptr = keys[i].c_str();
       const uint32_t length = static_cast<uint32_t>(keys[i].length());
       uint32_t key_length;
       const char * const key_ptr = _grn_dat_key(&ctx, dat, key_id, &key_length);
-      cut_assert_not_null(key_ptr);
+      cppcut_assert_not_null(key_ptr);
       cppcut_assert_equal(length, key_length);
       cppcut_assert_equal(keys[i], std::string(key_ptr, key_length));
     }
-    cut_assert_null(_grn_dat_key(&ctx, dat, GRN_ID_NIL, NULL));
+    cppcut_assert_null(_grn_dat_key(&ctx, dat, GRN_ID_NIL, NULL));
     cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
 
@@ -578,4 +713,57 @@ namespace test_dat
     }
     cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
+
+  void test_repair(void)
+  {
+    char dat_path[PATH_MAX];
+    std::sprintf(dat_path, "%s/%s", base_dir, "test_repair");
+
+    std::vector<std::string> keys;
+    create_keys(&keys, 1000, 6, 15);
+
+    grn_dat * const dat = create_trie(keys, dat_path);
+
+    cppcut_assert_equal(GRN_SUCCESS, grn_dat_repair(&ctx, dat));
+    cppcut_assert_equal(static_cast<unsigned int>(keys.size()),
+                        grn_dat_size(&ctx, dat));
+    cppcut_assert_equal(static_cast<grn_id>(keys.size()),
+                        grn_dat_curr_id(&ctx, dat));
+
+    for (std::size_t i = 0; i < keys.size(); ++i) {
+      const char * const ptr = keys[i].c_str();
+      const uint32_t length = static_cast<uint32_t>(keys[i].length());
+      cppcut_assert_equal(static_cast<grn_id>(i + 1),
+                          grn_dat_get(&ctx, dat, ptr, length, NULL));
+    }
+
+    for (std::size_t i = 0; i < keys.size(); i += 2) {
+      cppcut_assert_equal(GRN_SUCCESS,
+                          grn_dat_delete_by_id(&ctx, dat, i + 1, NULL));
+    }
+    cppcut_assert_equal(GRN_SUCCESS, grn_dat_repair(&ctx, dat));
+    cppcut_assert_equal(static_cast<unsigned int>(keys.size() / 2),
+                        grn_dat_size(&ctx, dat));
+
+    for (std::size_t i = 0; i < keys.size(); i += 2) {
+      const char * const ptr = keys[i].c_str();
+      const uint32_t length = static_cast<uint32_t>(keys[i].length());
+      int added;
+      cppcut_assert_equal(static_cast<grn_id>(i + 1),
+                          grn_dat_add(&ctx, dat, ptr, length, NULL, &added));
+      cppcut_assert_equal(1, added);
+    }
+    cppcut_assert_equal(GRN_SUCCESS, grn_dat_repair(&ctx, dat));
+    cppcut_assert_equal(static_cast<unsigned int>(keys.size()),
+                        grn_dat_size(&ctx, dat));
+
+    for (std::size_t i = 0; i < keys.size(); ++i) {
+      const char * const ptr = keys[i].c_str();
+      const uint32_t length = static_cast<uint32_t>(keys[i].length());
+      cppcut_assert_equal(static_cast<grn_id>(i + 1),
+                          grn_dat_get(&ctx, dat, ptr, length, NULL));
+    }
+
+    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+  }
 }
