@@ -24,6 +24,10 @@
 #include <str.h>
 
 void test_by_id(void);
+void test_by_filter(void);
+void test_by_invalid_filter(void);
+void test_by_id_and_filter(void);
+void test_by_all_options(void);
 void test_by_key(void);
 void test_referenced_record(void);
 void test_uint64(void);
@@ -125,6 +129,50 @@ test_by_id(void)
                                        "--output_columns _key"));
 }
 
+void
+test_by_filter(void)
+{
+  assert_send_command("delete Users --filter "
+                        "\"_key == \\\"tapo\\\"\"");
+  cut_assert_equal_string("[[[3],"
+                            "[[\"_key\",\"ShortText\"]],"
+                            "[\"mori\"],"
+                            "[\"yu\"],"
+                            "[\"tasukuchan\"]]]",
+                          send_command("select Users "
+                                       "--output_columns _key"));
+}
+
+void
+test_by_invalid_filter(void)
+{
+  grn_test_assert_send_command_error(
+    context,
+    GRN_SYNTAX_ERROR,
+    "Syntax error! ($)",
+    "delete Users --filter \"$\"");
+}
+
+void
+test_by_id_and_filter(void)
+{
+  grn_test_assert_send_command_error(
+    context,
+    GRN_INVALID_ARGUMENT,
+    "filter is used with id and/or key",
+    "delete Users --id 1 --filter \"true\"");
+}
+
+void
+test_by_all_options(void)
+{
+  grn_test_assert_send_command_error(
+    context,
+    GRN_INVALID_ARGUMENT,
+    "filter is used with id and/or key",
+    "delete Users --id 1 --key mori --filter \"true\"");
+}
+
 void
 test_by_delete(void)
 {
