@@ -2,7 +2,7 @@
 /*
   Copyright (C) 2010 Brazil
   Copyright (C) 2009  Ryo Onodera <onodera@clear-code.com>
-  Copyright (C) 2009-2010  Kouhei Sutou <kou@clear-code.com>
+  Copyright (C) 2009-2012  Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -183,6 +183,17 @@ data_patricia_trie_create(void)
            NULL);
 }
 
+static void
+data_double_array_trie_create(void)
+{
+  ADD_DATA("double-array trie",
+           "table_create Blog TABLE_DAT_KEY ShortText",
+           "Blog",
+           GRN_OBJ_TABLE_DAT_KEY,
+           "ShortText",
+           NULL);
+}
+
 static void
 data_array_create(void)
 {
@@ -216,6 +227,7 @@ data_table_create(void)
 {
   data_hash_table_create();
   data_patricia_trie_create();
+  data_double_array_trie_create();
   data_array_create();
   data_view_create();
 }
@@ -445,8 +457,8 @@ test_unsequantial_records_in_table_with_keys(void)
 {
   grn_obj *table;
   grn_id id, expected_id = 1;
-  char *keys[] = {"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"};
-  int i, n_keys = sizeof(keys)/sizeof(keys[0]);
+  const gchar *keys[] = {"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"};
+  int i, n_keys = sizeof(keys) / sizeof(keys[0]);
 
   table = table_create("Weekdays", GRN_OBJ_TABLE_HASH_KEY, "ShortText", NULL);
   grn_test_assert_context(context);
