@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2; coding: utf-8 -*- */
 /*
-  Copyright (C) 2008-2009  Kouhei Sutou <kou@cozmixng.org>
+  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,8 @@ void data_next_with_one_entry(void);
 void test_next_with_one_entry(gconstpointer data);
 void data_next_with_multi_entries(void);
 void test_next_with_multi_entries(gconstpointer data);
+void test_by_key_descending_max(void);
+void test_by_id_over_offset(void);
 void data_value(void);
 void test_value(gconstpointer data);
 void data_delete(void);
@@ -833,6 +835,39 @@ test_next_with_multi_entries(gconstpointer data)
                                 retrieve_all_keys());
 }
 
+void
+test_by_key_descending_max(void)
+{
+  default_cursor_min = g_strdup("0");
+  default_cursor_min_size = strlen(default_cursor_min);
+  default_cursor_max = g_strdup("9989");
+  default_cursor_max_size = strlen(default_cursor_max);
+  default_cursor_flags |= GRN_CURSOR_DESCENDING;
+
+  cut_assert_create_trie();
+
+  cut_assert_lookup_add("997");
+  cut_assert_lookup_add("999");
+  cut_assert_lookup_add("9998");
+
+  cut_assert_open_cursor();
+  gcut_assert_equal_list_string(gcut_take_new_list_string("997", NULL),
+                                retrieve_all_keys());
+}
+
+void
+test_by_id_over_offset(void)
+{
+  default_cursor_flags |= GRN_CURSOR_BY_ID;
+  default_cursor_offset = 1;
+
+  cut_assert_create_trie();
+
+  cut_assert_open_cursor();
+  gcut_assert_equal_list_string(NULL,
+                                retrieve_all_keys());
+}
+
 static void
 set_value_size(void)
 {
