@@ -15,7 +15,7 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-class HTTPSchemaTest < Test::Unit::TestCase
+module HTTPSchemaTests
   module Utils
     include GroongaHTTPTestUtils
 
@@ -44,7 +44,7 @@ class HTTPSchemaTest < Test::Unit::TestCase
     end
 
     def assert_table_list(expected)
-      response = get(command_path(:table_list))
+      response = get(command_path(:table_list, :output_type => output_type))
       expected = expected.collect do |values|
         id, name, flags, domain, range = values
         [id, name, nil, flags, domain, range]
@@ -57,7 +57,7 @@ class HTTPSchemaTest < Test::Unit::TestCase
                              ["range", "ShortText"]],
                             *expected],
                            response,
-                           :content_type => "application/json") do |actual|
+                           :content_type => content_type) do |actual|
         status, result = actual
         header, *values = result
         values = values.collect do |value|
@@ -69,6 +69,7 @@ class HTTPSchemaTest < Test::Unit::TestCase
     end
 
     def assert_column_list(expected, options)
+      options = options.merge(:output_type => output_type)
       response = get(command_path(:column_list, options))
       expected = expected.collect do |values|
         id, name, type, flags, domain, range, source = values
@@ -84,7 +85,7 @@ class HTTPSchemaTest < Test::Unit::TestCase
                              ["source", "ShortText"]],
                             *expected],
                            response,
-                           :content_type => "application/json") do |actual|
+                           :content_type => content_type) do |actual|
         status, result = actual
         header, *values = result
         values = values.collect do |value|
@@ -117,7 +118,7 @@ class HTTPSchemaTest < Test::Unit::TestCase
                                 :output_type => "unknown"))
     assert_response([[Result::UNKNOWN_ERROR, "should be implemented"]],
                     response,
-                    :content_type => "application/json")
+                    :content_type => content_type)
   end
 
   def test_column_list_empty
@@ -154,18 +155,19 @@ class HTTPSchemaTest < Test::Unit::TestCase
 
   def test_column_list_nonexistent
     response = get(command_path(:column_list,
-                                :table => "nonexistent"))
+                                :table => "nonexistent",
+                                :output_type => output_type))
     assert_error_response(Result::INVALID_ARGUMENT,
                           "table 'nonexistent' does not exist.",
                           response,
-                          :content_type => "application/json")
+                          :content_type => content_type)
   end
 
   def test_column_list_without_table
-    response = get(command_path(:column_list))
+    response = get(command_path(:column_list, :output_type => output_type))
     assert_error_response(Result::INVALID_ARGUMENT, "table '' does not exist.",
                           response,
-                          :content_type => "application/json")
+                          :content_type => content_type)
   end
 
   def test_column_list_with_invalid_output_type
@@ -176,7 +178,7 @@ class HTTPSchemaTest < Test::Unit::TestCase
                                 :output_type => "unknown"))
     assert_error_response(Result::UNKNOWN_ERROR, "should be implemented",
                           response,
-                          :content_type => "application/json")
+                          :content_type => content_type)
   end
 
   def test_column_list_with_invalid_output_type_without_table
@@ -185,63 +187,77 @@ class HTTPSchemaTest < Test::Unit::TestCase
                                 :output_type => "unknown"))
     assert_error_response(Result::UNKNOWN_ERROR, "should be implemented",
                           response,
-                          :content_type => "application/json")
+                          :content_type => content_type)
   end
 
   def test_table_create_without_name
-    response = get(command_path(:table_create))
+    response = get(command_path(:table_create, :output_type => output_type))
     assert_error_response(Result::INVALID_ARGUMENT,
-                          "should not create anonymous table",
+                          "[table][create] " +
+                            "should not create anonymous table",
                           response,
-                          :content_type => "application/json")
+                          :content_type => content_type)
   end
 
   def test_table_create_with_dot_name
-    response = get(command_path(:table_create, :name => "mori.daijiro"))
+    response = get(command_path(:table_create,
+                                :name => "mori.daijiro",
+                                :output_type => output_type))
     assert_error_response(Result::INVALID_ARGUMENT,
                           "[table][create]: " +
                           "name can't start with '_' " +
                           "and contains only 0-9, A-Z, a-z, #, - or _: " +
                           "<mori.daijiro>",
                           response,
-                          :content_type => "application/json")
+                          :content_type => content_type)
   end
 
   def test_table_create_with_under_score_started_name
-    response = get(command_path(:table_create, :name => "_mori"))
+    response = get(command_path(:table_create,
+                                :name => "_mori",
+                                :output_type => output_type))
     assert_error_response(Result::INVALID_ARGUMENT,
                           "[table][create]: " +
                           "name can't start with '_' " +
                           "and contains only 0-9, A-Z, a-z, #, - or _: " +
                           "<_mori>",
                           response,
-                          :content_type => "application/json")
+                          :content_type => content_type)
   end
 
   def test_table_create_with_under_score_name
-    response = get(command_path(:table_create, :name => "mori_daijiro"))
-    assert_success_response(response, :content_type => "application/json")
+    response = get(command_path(:table_create,
+                                :name => "mori_daijiro",
+                                :output_type => output_type))
+    assert_success_response(response, :content_type => content_type)
   end
 
   def test_table_create_with_colon_name
-    response = get(command_path(:table_create, :name => "daijiro:mori"))
+    response = get(command_path(:table_create,
+                                :name => "daijiro:mori",
+                                :output_type => output_type
+                                ))
     assert_error_response(Result::INVALID_ARGUMENT,
                           "[table][create]: " +
                           "name can't start with '_' " +
                           "and contains only 0-9, A-Z, a-z, #, - or _: " +
                           "<daijiro:mori>",
                           response,
-                          :content_type => "application/json")
+                          :content_type => content_type)
   end
 
   def test_table_create_with_duplicated_name
-    response = get(command_path(:table_create, :name => "daijiro"))
-    assert_success_response(response, :content_type => "application/json")
-    response = get(command_path(:table_create, :name => "daijiro"))
+    response = get(command_path(:table_create,
+                                :name => "daijiro",
+                                :output_type => output_type))
+    assert_success_response(response, :content_type => content_type)
+    response = get(command_path(:table_create,
+                                :name => "daijiro",
+                                :output_type => output_type))
     assert_error_response(Result::INVALID_ARGUMENT,
                           "already used name was assigned: <daijiro>",
                           response,
-                          :content_type => "application/json")
+                          :content_type => content_type)
   end
 
   def test_full_text_search
@@ -272,7 +288,7 @@ class HTTPSchemaTest < Test::Unit::TestCase
                   :query => "title:@column")
   end
 
-  class HashCreateTest < Test::Unit::TestCase
+  module HashCreateTests
     include Utils
 
     def test_simple
@@ -319,14 +335,17 @@ class HTTPSchemaTest < Test::Unit::TestCase
                           "null"]])
     end
 
-    def test_long_size_key
+    def test_big_size_key
       response = get(command_path(:table_create,
                                   :name => "users",
-                                  :key_type => "Text"))
-      assert_error_response(Result::UNKNOWN_ERROR,
-                            "should implement error case",
+                                  :key_type => "Text",
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "key size too big: " +
+                              "<users> <Text>(65536) (max:4096)",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -335,11 +354,14 @@ class HTTPSchemaTest < Test::Unit::TestCase
       response = get(command_path(:table_create,
                                   :name => "users",
                                   :flags => Key::SIS,
-                                  :key_type => "ShortText"))
-      assert_error_response(Result::UNKNOWN_ERROR,
-                            "SIS is invalid flag for hash",
+                                  :key_type => "ShortText",
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "key with SIS isn't available " +
+                              "for hash table: <users>",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -347,11 +369,14 @@ class HTTPSchemaTest < Test::Unit::TestCase
     def test_nonexistent_key_type
       response = get(command_path(:table_create,
                                   :name => "users",
-                                  :key_type => "nonexistent"))
+                                  :key_type => "nonexistent",
+                                  :output_type => output_type))
       assert_error_response(Result::INVALID_ARGUMENT,
-                            "key type doesn't exist: <nonexistent>",
+                            "[table][create] " +
+                              "key type doesn't exist: " +
+                              "<users> (nonexistent)",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -359,11 +384,14 @@ class HTTPSchemaTest < Test::Unit::TestCase
     def test_invalid_key_type
       response = get(command_path(:table_create,
                                   :name => "users",
-                                  :key_type => "table_create"))
-      assert_error_response(Result::UNKNOWN_ERROR,
-                            "should implement error case",
+                                  :key_type => "table_create",
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "key type must be type or table: " +
+                              "<users> (table_create)",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -380,17 +408,50 @@ class HTTPSchemaTest < Test::Unit::TestCase
     def test_nonexistent_value_type
       response = get(command_path(:table_create,
                                   :name => "users",
-                                  :value_type => "nonexistent"))
+                                  :value_type => "nonexistent",
+                                  :output_type => output_type))
       assert_error_response(Result::INVALID_ARGUMENT,
-                            "value type doesn't exist: <nonexistent>",
+                            "[table][create] " +
+                              "value type doesn't exist: " +
+                              "<users> (nonexistent)",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
+
+      assert_table_list([])
+    end
+
+    def test_invalid_value_type
+      response = get(command_path(:table_create,
+                                  :name => "users",
+                                  :value_type => "table_create",
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "value type must be type or table: " +
+                              "<users> (table_create)",
+                            response,
+                            :content_type => content_type)
+
+      assert_table_list([])
+    end
+
+    def test_variable_size_value_type
+      response = get(command_path(:table_create,
+                                  :name => "users",
+                                  :value_type => "ShortText",
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "value type must be fixed size: " +
+                              "<users> (ShortText)",
+                            response,
+                            :content_type => content_type)
 
       assert_table_list([])
     end
   end
 
-  class PatriciaTrieCreateTest < Test::Unit::TestCase
+  module PatriciaTrieCreateTests
     include Utils
 
     def test_simple
@@ -440,15 +501,18 @@ class HTTPSchemaTest < Test::Unit::TestCase
                           "null"]])
     end
 
-    def test_long_size_key
+    def test_big_size_key
       response = get(command_path(:table_create,
                                   :name => "users",
                                   :flags => Table::PAT_KEY,
-                                  :key_type => "Text"))
-      assert_error_response(Result::UNKNOWN_ERROR,
-                            "should implement error case",
+                                  :key_type => "Text",
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "key size too big: " +
+                              "<users> <Text>(65536) (max:4096)",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -468,11 +532,14 @@ class HTTPSchemaTest < Test::Unit::TestCase
       response = get(command_path(:table_create,
                                   :name => "users",
                                   :flags => Table::PAT_KEY,
-                                  :key_type => "nonexistent"))
+                                  :key_type => "nonexistent",
+                                  :output_type => output_type))
       assert_error_response(Result::INVALID_ARGUMENT,
-                            "key type doesn't exist: <nonexistent>",
+                            "[table][create] " +
+                              "key type doesn't exist: " +
+                              "<users> (nonexistent)",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -481,11 +548,14 @@ class HTTPSchemaTest < Test::Unit::TestCase
       response = get(command_path(:table_create,
                                   :name => "users",
                                   :flags => Table::PAT_KEY,
-                                  :key_type => "table_create"))
-      assert_error_response(Result::UNKNOWN_ERROR,
-                            "should implement error case",
+                                  :key_type => "table_create",
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "key type must be type or table: " +
+                              "<users> (table_create)",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -505,17 +575,52 @@ class HTTPSchemaTest < Test::Unit::TestCase
       response = get(command_path(:table_create,
                                   :name => "users",
                                   :flags => Table::PAT_KEY,
-                                  :value_type => "nonexistent"))
+                                  :value_type => "nonexistent",
+                                  :output_type => output_type))
       assert_error_response(Result::INVALID_ARGUMENT,
-                            "value type doesn't exist: <nonexistent>",
+                            "[table][create] " +
+                              "value type doesn't exist: " +
+                              "<users> (nonexistent)",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
+
+      assert_table_list([])
+    end
+
+    def test_invalid_value_type
+      response = get(command_path(:table_create,
+                                  :name => "users",
+                                  :flags => Table::PAT_KEY,
+                                  :value_type => "table_create",
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "value type must be type or table: " +
+                              "<users> (table_create)",
+                            response,
+                            :content_type => content_type)
+
+      assert_table_list([])
+    end
+
+    def test_variable_size_value_type
+      response = get(command_path(:table_create,
+                                  :name => "users",
+                                  :flags => Table::PAT_KEY,
+                                  :value_type => "ShortText",
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "value type must be fixed size: " +
+                              "<users> (ShortText)",
+                            response,
+                            :content_type => content_type)
 
       assert_table_list([])
     end
   end
 
-  class ArrayCreateTest < Test::Unit::TestCase
+  module ArrayCreateTests
     include Utils
 
     def test_simple
@@ -530,11 +635,14 @@ class HTTPSchemaTest < Test::Unit::TestCase
     def test_normalize_key
       response = get(command_path(:table_create,
                                   :name => "users",
-                                  :flags => Table::NO_KEY | Key::NORMALIZE))
-      assert_error_response(Result::UNKNOWN_ERROR,
-                            "key normalization isn't available",
+                                  :flags => Table::NO_KEY | Key::NORMALIZE,
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "key normalization isn't available " +
+                              "for no key table: <users>",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -543,11 +651,14 @@ class HTTPSchemaTest < Test::Unit::TestCase
       response = get(command_path(:table_create,
                                   :name => "users",
                                   :flags => Table::NO_KEY,
-                                  :key_type => "ShortText"))
+                                  :key_type => "ShortText",
+                                  :output_type => output_type))
       assert_error_response(Result::INVALID_ARGUMENT,
-                            "key_type assigned for no key table: <users>",
+                            "[table][create] " +
+                              "key isn't available for no key table: " +
+                              "<users> (ShortText)",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -555,11 +666,14 @@ class HTTPSchemaTest < Test::Unit::TestCase
     def test_sis
       response = get(command_path(:table_create,
                                   :name => "users",
-                                  :flags => Table::NO_KEY | Key::SIS))
-      assert_error_response(Result::UNKNOWN_ERROR,
-                            "SIS key isn't available",
+                                  :flags => Table::NO_KEY | Key::SIS,
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "key with SIS isn't available " +
+                              "for no key table: <users>",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -596,17 +710,20 @@ class HTTPSchemaTest < Test::Unit::TestCase
       response = get(command_path(:table_create,
                                   :name => "users",
                                   :flags => Table::NO_KEY,
-                                  :value_type => "nonexistent"))
+                                  :value_type => "nonexistent",
+                                  :output_type => output_type))
       assert_error_response(Result::INVALID_ARGUMENT,
-                            "value type doesn't exist: <nonexistent>",
+                            "[table][create] " +
+                              "value type doesn't exist: " +
+                              "<users> (nonexistent)",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
   end
 
-  class ViewCreateTest < Test::Unit::TestCase
+  module ViewCreateTests
     include Utils
 
     def test_simple
@@ -620,11 +737,14 @@ class HTTPSchemaTest < Test::Unit::TestCase
     def test_normalize_key
       response = get(command_path(:table_create,
                                   :name => "users",
-                                  :flags => Table::VIEW | Key::NORMALIZE))
-      assert_error_response(Result::UNKNOWN_ERROR,
-                            "key normalization isn't available",
+                                  :flags => Table::VIEW | Key::NORMALIZE,
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "key normalization isn't available " +
+                              "for view table: <users>",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -633,11 +753,14 @@ class HTTPSchemaTest < Test::Unit::TestCase
       response = get(command_path(:table_create,
                                   :name => "users",
                                   :flags => Table::VIEW,
-                                  :key_type => "ShortText"))
-      assert_error_response(Result::UNKNOWN_ERROR,
-                            "key isn't supported",
+                                  :key_type => "ShortText",
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "key isn't available for view table: " +
+                              "<users> (ShortText)",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -645,11 +768,14 @@ class HTTPSchemaTest < Test::Unit::TestCase
     def test_sis
       response = get(command_path(:table_create,
                                   :name => "users",
-                                  :flags => Table::VIEW | Key::SIS))
-      assert_error_response(Result::UNKNOWN_ERROR,
-                            "SIS key isn't available",
+                                  :flags => Table::VIEW | Key::SIS,
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "key with SIS isn't available " +
+                              "for view table: <users>",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -658,17 +784,20 @@ class HTTPSchemaTest < Test::Unit::TestCase
       response = get(command_path(:table_create,
                                   :name => "users",
                                   :flags => Table::VIEW,
-                                  :value_type => "Int32"))
-      assert_error_response(Result::UNKNOWN_ERROR,
-                            "value isn't available",
+                                  :value_type => "Int32",
+                                  :output_type => output_type))
+      assert_error_response(Result::INVALID_ARGUMENT,
+                            "[table][create] " +
+                              "value isn't available for view table: " +
+                              "<users> (Int32)",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
   end
 
-  class SymbolFlagsTest < Test::Unit::TestCase
+  module SymbolFlagsTests
     include Utils
 
     def test_table_create_single_symbol
@@ -691,32 +820,35 @@ class HTTPSchemaTest < Test::Unit::TestCase
 
     def test_table_create_combined_symbols
       table_id = table_create("books",
-                              :flags => "TABLE_NO_KEY|KEY_NORMALIZE")
+                              :flags => "TABLE_HASH_KEY|KEY_NORMALIZE",
+                              :key_type => "ShortText")
       assert_table_list([[table_id,
                           "books",
-                          "TABLE_NO_KEY|KEY_NORMALIZE|PERSISTENT",
-                          "null",
+                          "TABLE_HASH_KEY|KEY_NORMALIZE|PERSISTENT",
+                          "ShortText",
                           "null"]])
     end
 
     def test_table_create_combined_symbols_with_whitespaces
       table_id = table_create("books",
-                              :flags => " TABLE_NO_KEY | KEY_NORMALIZE ")
+                              :flags => " TABLE_HASH_KEY | KEY_NORMALIZE ",
+                              :key_type => "ShortText")
       assert_table_list([[table_id,
                           "books",
-                          "TABLE_NO_KEY|KEY_NORMALIZE|PERSISTENT",
-                          "null",
+                          "TABLE_HASH_KEY|KEY_NORMALIZE|PERSISTENT",
+                          "ShortText",
                           "null"]])
     end
 
     def test_table_create_invalid_symbol
       response = get(command_path(:table_create,
                                   :name => "books",
-                                  :flags => "INVALID_SYMBOL"))
+                                  :flags => "INVALID_SYMBOL",
+                                  :output_type => output_type))
       assert_error_response(Result::INVALID_ARGUMENT,
                             "invalid flags option: INVALID_SYMBOL",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
 
       assert_table_list([])
     end
@@ -779,11 +911,12 @@ class HTTPSchemaTest < Test::Unit::TestCase
                                   :table => "books",
                                   :name => "name",
                                   :flags => "INVALID_SYMBOL",
-                                  :type => "ShortText"))
+                                  :type => "ShortText",
+                                  :output_type => output_type))
       assert_error_response(Result::INVALID_ARGUMENT,
                             "invalid flags option: INVALID_SYMBOL",
                             response,
-                            :content_type => "application/json")
+                            :content_type => content_type)
       assert_column_list([], :table => "books")
     end
 
@@ -799,3 +932,63 @@ class HTTPSchemaTest < Test::Unit::TestCase
     end
   end
 end
+
+class JSONHTTPSchemaTests < Test::Unit::TestCase
+  include HTTPSchemaTests
+  include Format::JSON
+
+  class JSONHashCreateTest < Test::Unit::TestCase
+    include HTTPSchemaTests::HashCreateTests
+    include Format::JSON
+  end
+
+  class JSONPatriciaTrieCreateTest < Test::Unit::TestCase
+    include HTTPSchemaTests::PatriciaTrieCreateTests
+    include Format::JSON
+  end
+
+  class JSONArrayCreateTest < Test::Unit::TestCase
+    include HTTPSchemaTests::ArrayCreateTests
+    include Format::JSON
+  end
+
+  class JSONViewCreateTest < Test::Unit::TestCase
+    include HTTPSchemaTests::ViewCreateTests
+    include Format::JSON
+  end
+
+  class JSONSymbolFlagsTest < Test::Unit::TestCase
+    include HTTPSchemaTests::SymbolFlagsTests
+    include Format::JSON
+  end
+end
+
+class MessagePackHTTPSchemaTests < Test::Unit::TestCase
+  include HTTPSchemaTests
+  include Format::MessagePack
+
+  class MessagePackHashCreateTest < Test::Unit::TestCase
+    include HTTPSchemaTests::HashCreateTests
+    include Format::MessagePack
+  end
+
+  class MessagePackPatriciaTrieCreateTest < Test::Unit::TestCase
+    include HTTPSchemaTests::PatriciaTrieCreateTests
+    include Format::MessagePack
+  end
+
+  class MessagePackArrayCreateTest < Test::Unit::TestCase
+    include HTTPSchemaTests::ArrayCreateTests
+    include Format::MessagePack
+  end
+
+  class MessagePackViewCreateTest < Test::Unit::TestCase
+    include HTTPSchemaTests::ViewCreateTests
+    include Format::MessagePack
+  end
+
+  class MessagePackSymbolFlagsTest < Test::Unit::TestCase
+    include HTTPSchemaTests::SymbolFlagsTests
+    include Format::MessagePack
+  end
+end
