@@ -338,6 +338,7 @@ data_urlenc(void)
             " 日本語です。 ",
             -1);
   ADD_DATUM("percent", "%251%252%253", "%1%2%3", -1);
+  ADD_DATUM("plus", "%2B%20%2B", "+ +", -1);
 
 #undef ADD_DATUM
 }
@@ -520,8 +521,7 @@ test_url_path_normalize_invalid(gconstpointer data)
 
   grn_str_url_path_normalize(&context, input, strlen(input),
                              buffer, BUFFER_SIZE);
-  /* NOTE: not in GRN_API_ENTER, rc is not set. */
-  grn_test_assert_error(GRN_SUCCESS, error_message, &context);
+  grn_test_assert_error(GRN_INVALID_ARGUMENT, error_message, &context);
 #undef BUFFER_SIZE
 }
 
